﻿/*
 * AppManager.cs
 * Copyright (c) 2008-2009 kbinani
 *
 * This file is part of LipSync.
 *
 * LipSync is free software; you can redistribute it and/or
 * modify it under the terms of the BSD License.
 *
 * LipSync is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
using System;
using System.Collections.Generic;
using System.Drawing;
using System.IO;
using System.Reflection;
using System.Windows.Forms;

namespace LipSync {

    public static class AppManager {
        public static bool Playing = false;
        public static SettingsEx SaveData;
        public static EnvSettings Config;
        internal static List<Command> m_commands = new List<Command>();
        internal static int m_command_position = -1;
        private static readonly Bitmap m_author_list = null;
        /// <summary>
        /// telopの描画に必要な最大のトラック数
        /// </summary>
        public static int MaxTelopLanes = 0;
        private static bool m_edited;

        /// <summary>
        /// Editedプロパティが変更された時発生します
        /// </summary>
        public static event EventHandler EditedChanged;

        #region _AUTHOR_LIST
        private static byte[] _AUTHOR_LSIT = new byte[] { 0x89, 0x50, 0x4e, 0x47, 0xd, 0xa, 0x1a, 0xa, 0x0, 0x0, 0x0, 0xd, 0x49, 0x48, 0x44, 0x52, 0x0, 0x0, 0x1, 0x32, 
                          0x0, 0x0, 0x2, 0x6c, 0x8, 0x6, 0x0, 0x0, 0x0, 0x7e, 0xaa, 0x2f, 0xdf, 0x0, 0x0, 0x0, 0x1, 0x73, 0x52, 0x47, 
                          0x42, 0x0, 0xae, 0xce, 0x1c, 0xe9, 0x0, 0x0, 0x0, 0x4, 0x67, 0x41, 0x4d, 0x41, 0x0, 0x0, 0xb1, 0x8f, 0xb, 0xfc, 
                          0x61, 0x5, 0x0, 0x0, 0x0, 0x20, 0x63, 0x48, 0x52, 0x4d, 0x0, 0x0, 0x7a, 0x26, 0x0, 0x0, 0x80, 0x84, 0x0, 0x0, 
                          0xfa, 0x0, 0x0, 0x0, 0x80, 0xe8, 0x0, 0x0, 0x75, 0x30, 0x0, 0x0, 0xea, 0x60, 0x0, 0x0, 0x3a, 0x98, 0x0, 0x0, 
                          0x17, 0x70, 0x9c, 0xba, 0x51, 0x3c, 0x0, 0x0, 0x25, 0xc2, 0x49, 0x44, 0x41, 0x54, 0x78, 0x5e, 0xed, 0xdd, 0x8b, 0xb5, 
                          0xe4, 0x38, 0xb9, 0x6, 0x50, 0x2, 0xb8, 0x9, 0xdc, 0x4, 0x6e, 0x2, 0x24, 0x40, 0x4, 0x44, 0x40, 0x6, 0x64, 0x40, 
                          0xa, 0xa4, 0x40, 0xc, 0x24, 0x41, 0x16, 0x24, 0xc3, 0x6d, 0x31, 0x2d, 0xd0, 0x68, 0xf4, 0xf8, 0xe5, 0x47, 0x95, 0x1f, 
                          0xbb, 0xd7, 0xea, 0x35, 0x7d, 0xca, 0xb2, 0x2c, 0x6d, 0xd9, 0xdf, 0x91, 0x5c, 0xae, 0x9a, 0xdf, 0xfd, 0xce, 0x1f, 0x2, 
                          0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0xc0, 0x26, 0x81, 0x7f, 0xfe, 
                          0xd8, 0x2b, 0xfd, 0x1d, 0xfd, 0x89, 0x94, 0x69, 0xed, 0xff, 0xc7, 0x1f, 0x2f, 0xfe, 0xe3, 0x67, 0xfd, 0xa9, 0x8e, 0xf4, 
                          0xef, 0xbf, 0x6c, 0x6a, 0xa5, 0x9d, 0x8, 0x10, 0x20, 0x30, 0x10, 0x88, 0x84, 0x54, 0xa4, 0x4c, 0x7d, 0x88, 0x3f, 0xfd, 
                          0x78, 0xe1, 0x5f, 0x3f, 0xff, 0xe6, 0xfd, 0xf3, 0xcf, 0x7f, 0x35, 0x22, 0x4, 0x8, 0x10, 0x38, 0x52, 0x60, 0x4b, 0x48, 
                          0x45, 0x8e, 0x9f, 0xeb, 0xfd, 0x43, 0x51, 0xf8, 0xcf, 0xc5, 0xec, 0x2c, 0x52, 0x87, 0x32, 0x4, 0x8, 0x10, 0x8, 0x9, 
                          0x44, 0x82, 0xac, 0x2e, 0x93, 0x7f, 0x2e, 0x83, 0x29, 0xcd, 0xc0, 0xca, 0x3f, 0xa9, 0x4c, 0x9a, 0x81, 0x8d, 0x96, 0x92, 
                          0x79, 0xd9, 0xf9, 0xbf, 0x3f, 0x77, 0x4c, 0xff, 0xcd, 0x4b, 0xd0, 0xf4, 0x52, 0x3e, 0x4e, 0xaa, 0x3b, 0x97, 0x4d, 0xff, 
                          0xfd, 0x7d, 0x75, 0xac, 0xb4, 0x3d, 0x97, 0xfd, 0x5b, 0xa8, 0xd7, 0xa, 0x11, 0x20, 0xf0, 0x28, 0x81, 0xad, 0x41, 0x56, 
                          0x2e, 0x1b, 0xf3, 0xbf, 0xd3, 0x3d, 0xb1, 0xfc, 0x27, 0x2d, 0x1f, 0xcb, 0x32, 0xe9, 0xe7, 0x1c, 0x58, 0xb9, 0x4c, 0xa, 
                          0x9d, 0x54, 0x26, 0x87, 0x60, 0x5e, 0x8e, 0xe6, 0x30, 0xca, 0x61, 0x98, 0xca, 0x94, 0xff, 0x4e, 0x61, 0x96, 0xff, 0xa4, 
                          0x63, 0xe6, 0xed, 0x91, 0xf0, 0x7c, 0xd4, 0xe0, 0xe9, 0xc, 0x1, 0x2, 0xbf, 0x8, 0xec, 0x9, 0xb2, 0x1c, 0x38, 0x39, 
                          0x90, 0xca, 0x80, 0x49, 0x75, 0xa7, 0xd9, 0x58, 0x1d, 0x46, 0xe5, 0x8c, 0x29, 0x7, 0xd7, 0xdf, 0x7f, 0xe, 0x46, 0xfa, 
                          0x6f, 0x19, 0x6c, 0x79, 0xdf, 0xbc, 0x4f, 0x19, 0x5a, 0x79, 0xfc, 0xd2, 0x31, 0xd3, 0x3e, 0x7f, 0xf8, 0xf1, 0x37, 0xcd, 
                          0xd4, 0xca, 0x19, 0x9d, 0x31, 0x26, 0x40, 0xe0, 0x25, 0x2, 0x5b, 0x83, 0x2c, 0xed, 0x57, 0x2f, 0x9, 0x7b, 0xef, 0x7e, 
                          0xd6, 0x81, 0x96, 0x83, 0x29, 0x2f, 0x25, 0xf3, 0x7e, 0xbd, 0x25, 0x6c, 0x39, 0x14, 0x91, 0x32, 0x2f, 0x19, 0x3a, 0xdd, 
                          0x24, 0x40, 0x20, 0xb, 0x7c, 0x22, 0xc8, 0xf2, 0xb1, 0x52, 0xa0, 0xe5, 0x65, 0x60, 0x3d, 0xa3, 0xca, 0xb3, 0xb3, 0x72, 
                          0x56, 0xd7, 0x6a, 0x9b, 0x20, 0x73, 0xee, 0x12, 0x20, 0xf0, 0x1b, 0x81, 0xad, 0x41, 0x96, 0x2, 0x29, 0xcf, 0xac, 0xf2, 
                          0xfd, 0xb0, 0x56, 0x8, 0xa5, 0x37, 0x4, 0xf2, 0x9f, 0xb4, 0xfc, 0xab, 0x8f, 0x57, 0xee, 0x9b, 0xea, 0x2c, 0x1f, 0xcd, 
                          0x88, 0x4, 0x59, 0x5e, 0x5a, 0xa6, 0x65, 0x67, 0x5e, 0x5a, 0xf6, 0x66, 0x86, 0x86, 0x9f, 0x0, 0x81, 0x87, 0xa, 0xe4, 
                          0xfb, 0x50, 0x39, 0x34, 0xca, 0xff, 0xf6, 0x66, 0x6d, 0xbd, 0x9b, 0xf0, 0xe5, 0xcd, 0xfe, 0x3c, 0xfb, 0xaa, 0x6f, 0xc4, 
                          0x97, 0xf7, 0xc0, 0x52, 0xfd, 0x29, 0xdc, 0xf2, 0x9b, 0x2, 0xf9, 0x5e, 0xd7, 0x68, 0xb6, 0x58, 0x87, 0x5b, 0xeb, 0x66, 
                          0xbf, 0x77, 0x2e, 0x1f, 0x7a, 0xb2, 0xea, 0x16, 0x81, 0x9e, 0x40, 0x2b, 0xc0, 0x66, 0xcb, 0xb7, 0xbc, 0x7d, 0xf4, 0xf8, 
                          0x45, 0x3a, 0x5e, 0xa, 0xb3, 0xfa, 0xc9, 0xfe, 0x32, 0xec, 0xca, 0xc0, 0xaa, 0x97, 0x9c, 0x69, 0x5b, 0x64, 0x46, 0x96, 
                          0xca, 0x79, 0xfc, 0xc2, 0xf9, 0x4d, 0x80, 0xc0, 0xb2, 0x40, 0x64, 0x39, 0xba, 0x52, 0x69, 0x5e, 0x1e, 0xd6, 0xef, 0x7a, 
                          0xae, 0xd4, 0xa1, 0x2c, 0x1, 0x2, 0x4, 0x96, 0x4, 0xce, 0xa, 0xb2, 0xfa, 0xa1, 0xda, 0xa5, 0x46, 0x29, 0x4c, 0x80, 
                          0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 
                          0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 
                          0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 
                          0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 
                          0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 
                          0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 
                          0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 
                          0x10, 0x20, 0x40, 0x80, 0xc0, 0xa3, 0x5, 0xfe, 0x75, 0x50, 0xef, 0x8e, 0xaa, 0xa7, 0xd5, 0x9c, 0x33, 0xeb, 0x5e, 0xed, 
                          0xfe, 0xa8, 0x2d, 0x57, 0x6a, 0xe7, 0x6a, 0xbf, 0x94, 0x27, 0x40, 0xe0, 0x87, 0xc0, 0x99, 0x17, 0xf1, 0x99, 0x75, 0xaf, 
                          0xe, 0x9e, 0x20, 0x5b, 0x15, 0x53, 0x9e, 0xc0, 0x4d, 0x4, 0xce, 0xe, 0x9a, 0xb3, 0xeb, 0x8f, 0x32, 0xb, 0xb1, 0xa8, 
                          0x94, 0x72, 0x4, 0x3e, 0x28, 0x50, 0x5f, 0x98, 0xe9, 0xe7, 0xfc, 0x77, 0xd6, 0x8c, 0xb2, 0x5c, 0xa4, 0x9e, 0x56, 0x8, 
                          0x94, 0xaf, 0xf5, 0x8e, 0x1d, 0xa9, 0x3b, 0xb5, 0x35, 0x97, 0x6b, 0xb5, 0x7f, 0xb4, 0x2d, 0xef, 0xdb, 0xeb, 0xf7, 0xa8, 
                          0x9f, 0xa5, 0x51, 0x7d, 0x8c, 0xba, 0x6f, 0xb5, 0x67, 0x59, 0x7e, 0x66, 0x6d, 0x3b, 0x1, 0x2, 0x3, 0x81, 0xd1, 0xc5, 
                          0x16, 0x9d, 0x7d, 0xd4, 0x1, 0xd0, 0xa, 0x9e, 0x32, 0x68, 0x72, 0x73, 0xa2, 0xc7, 0x5e, 0x29, 0xd7, 0x2b, 0x3b, 0x6a, 
                          0x63, 0xaf, 0xbd, 0x75, 0x9b, 0x67, 0x1, 0x3f, 0xb, 0xd0, 0x56, 0xe8, 0x39, 0x39, 0x9, 0x10, 0x38, 0x40, 0xa0, 0x35, 
                          0x23, 0x9a, 0x55, 0x3b, 0x9a, 0x59, 0xad, 0x6c, 0x1b, 0xcd, 0x48, 0x5a, 0x81, 0x14, 0x99, 0xd1, 0xf5, 0xc2, 0x22, 0x1a, 
                          0xae, 0xf5, 0xcc, 0xae, 0x37, 0x8b, 0x6a, 0x19, 0x6d, 0xe9, 0xfb, 0xcc, 0xda, 0x76, 0x2, 0x4, 0x2, 0x2, 0xbd, 0x8b, 
                          0x6f, 0x34, 0xfb, 0x98, 0x5d, 0xb0, 0xe5, 0x12, 0xb1, 0x37, 0x13, 0x6a, 0x5, 0x68, 0xbd, 0x5f, 0x3d, 0x73, 0x9b, 0x1d, 
                          0x77, 0x65, 0xe9, 0xd6, 0x5a, 0x6, 0x96, 0xc7, 0x6f, 0xcd, 0x20, 0x7b, 0xaf, 0xb5, 0x66, 0x98, 0xa3, 0xb6, 0x8f, 0x66, 
                          0xba, 0x81, 0x21, 0x53, 0x84, 0x0, 0x81, 0xe8, 0x8c, 0x65, 0x74, 0xd1, 0x46, 0x97, 0x62, 0xa3, 0x59, 0xcb, 0x68, 0xb9, 
                          0xb8, 0x35, 0x90, 0x8e, 0xda, 0xaf, 0x17, 0x4c, 0xd1, 0xa5, 0x76, 0xcb, 0x78, 0xa5, 0xbf, 0xce, 0x52, 0x2, 0x4, 0x16, 
                          0x4, 0x66, 0x17, 0x57, 0xef, 0xc2, 0x1d, 0x2d, 0x47, 0x47, 0x21, 0x97, 0xc3, 0x31, 0x52, 0xa6, 0x15, 0x26, 0xb3, 0x0, 
                          0xed, 0xf5, 0xa7, 0x37, 0x2b, 0x6c, 0x85, 0x75, 0xb4, 0x8e, 0x56, 0x68, 0xce, 0xda, 0x37, 0x9b, 0xd1, 0x2d, 0xc, 0x9d, 
                          0xa2, 0x4, 0x8, 0x8c, 0x66, 0x1c, 0xf5, 0xf2, 0xaa, 0xa7, 0x55, 0x86, 0x43, 0xeb, 0x2, 0xee, 0x2d, 0x4d, 0x47, 0xe1, 
                          0xd8, 0xda, 0x27, 0x5a, 0x77, 0xbd, 0x54, 0xec, 0xcd, 0x8a, 0x7a, 0xcb, 0xd3, 0x51, 0x7b, 0xcb, 0xba, 0x47, 0x1e, 0x65, 
                          0x50, 0x8f, 0x8e, 0xd3, 0x9b, 0x15, 0x3b, 0x33, 0x9, 0x10, 0x78, 0xb1, 0xc0, 0x96, 0x25, 0xdf, 0x37, 0xb8, 0xdc, 0x1b, 
                          0xfb, 0x86, 0xba, 0x63, 0x12, 0xb8, 0x89, 0x80, 0x20, 0xbb, 0xc9, 0x40, 0x69, 0x26, 0x1, 0x2, 0x7d, 0x81, 0xab, 0x7, 
                          0x59, 0x6f, 0xd9, 0x6a, 0x4c, 0x9, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 
                          0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0xf8, 0x96, 0xc0, 0xd6, 0x77, 0x19, 
                          0xcf, 0x7e, 0xe, 0xeb, 0xec, 0xfa, 0xbf, 0xe5, 0xed, 0xb8, 0x4, 0x8, 0x9c, 0x20, 0xb0, 0x35, 0xc8, 0x4e, 0x68, 0x8a, 
                          0x2a, 0x9, 0x10, 0x20, 0xb0, 0x4d, 0x40, 0x90, 0x6d, 0x73, 0xb3, 0x17, 0x1, 0x2, 0x17, 0x12, 0x88, 0x7e, 0xb8, 0x7a, 
                          0x6b, 0xb9, 0xd4, 0xd5, 0xde, 0x67, 0x46, 0x23, 0x9f, 0xc9, 0xbc, 0x10, 0x95, 0xa6, 0x10, 0x20, 0x70, 0x55, 0x81, 0xde, 
                          0x37, 0x4c, 0x94, 0x1, 0x94, 0xdb, 0x1e, 0xfd, 0x36, 0x8a, 0x59, 0x9d, 0x65, 0x7d, 0xa3, 0x3a, 0xaf, 0x6a, 0xa6, 0x5d, 
                          0x4, 0x8, 0x5c, 0x4c, 0x60, 0xf4, 0x6d, 0x12, 0x91, 0x59, 0x58, 0xe, 0xbc, 0xb2, 0x5b, 0xd1, 0xe5, 0x6a, 0xb4, 0xfe, 
                          0x8b, 0x91, 0x69, 0xe, 0x1, 0x2, 0x57, 0x13, 0xe8, 0x2d, 0xfb, 0x66, 0x1, 0x15, 0x9d, 0x75, 0xd5, 0x4b, 0xcb, 0xe8, 
                          0x7e, 0xde, 0xb5, 0xbc, 0xda, 0x99, 0xa2, 0x3d, 0x4, 0x2e, 0x2c, 0x10, 0xd, 0x96, 0x3a, 0xd8, 0xa2, 0xfb, 0xad, 0xcc, 
                          0xba, 0x46, 0x75, 0x5e, 0x98, 0x50, 0xd3, 0x8, 0x10, 0xf8, 0xb6, 0x40, 0x34, 0x90, 0x8e, 0x8, 0xb2, 0xfa, 0x9b, 0x27, 
                          0x56, 0x42, 0xee, 0xdb, 0x4e, 0x8e, 0x4f, 0x80, 0xc0, 0x85, 0x5, 0x66, 0x61, 0x32, 0x7b, 0xc7, 0x71, 0xb6, 0x4, 0x2d, 
                          0x97, 0x96, 0xa3, 0x30, 0x9c, 0x6d, 0xbb, 0x30, 0xa1, 0xa6, 0x11, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 
                          0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 
                          0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0xe0, 0x72, 0x2, 0xd1, 0xcf, 0x3a, 0x1e, 0xd9, 0xf0, 0x33, 0x3e, 
                          0x52, 0x74, 0x46, 0x9d, 0x47, 0xf6, 0x59, 0x5d, 0x4, 0x8, 0x9c, 0x28, 0x70, 0x76, 0x90, 0xb5, 0xea, 0x3f, 0x23, 0x74, 
                          0x8e, 0xaa, 0xf3, 0xa8, 0x7a, 0x4e, 0x1c, 0x32, 0x55, 0x13, 0x20, 0x50, 0xa, 0xcc, 0x2e, 0xda, 0xd9, 0xf6, 0x88, 0xe6, 
                          0x27, 0x82, 0xec, 0x88, 0x76, 0xe6, 0xbe, 0x1c, 0x59, 0x57, 0xc4, 0x47, 0x19, 0x2, 0xaf, 0x16, 0x98, 0x7d, 0x1c, 0xa8, 
                          0xfe, 0xac, 0x62, 0x79, 0xa1, 0x8e, 0xbe, 0x8e, 0xa7, 0xbe, 0xa0, 0x67, 0xf5, 0xcc, 0x66, 0x74, 0xbd, 0xcf, 0x4c, 0xae, 
                          0xd6, 0x5b, 0xb6, 0x79, 0xf4, 0x51, 0xa9, 0xd4, 0xfe, 0x5e, 0x78, 0xf6, 0x8e, 0x59, 0xdb, 0xb4, 0xea, 0x6f, 0xed, 0x2b, 
                          0xf4, 0x5e, 0x7d, 0x9, 0xea, 0xfc, 0x5e, 0x81, 0xc8, 0x67, 0x1e, 0x5b, 0x33, 0x8c, 0x72, 0xbf, 0xe8, 0x45, 0x3d, 0xab, 
                          0xa7, 0x17, 0x1c, 0xbd, 0x19, 0x4e, 0x2f, 0xd8, 0x5a, 0xf5, 0x8c, 0xda, 0x5b, 0x6f, 0x1b, 0xcd, 0xa8, 0x66, 0xc1, 0x37, 
                          0x9a, 0xa5, 0xae, 0xec, 0xbb, 0x77, 0x5c, 0xed, 0x4f, 0xe0, 0xd5, 0x2, 0xbd, 0x8b, 0xba, 0xc, 0x87, 0xd5, 0x25, 0x5e, 
                          0xef, 0x2, 0x3e, 0xaa, 0x9e, 0xc8, 0x52, 0x2e, 0xd2, 0xaf, 0x59, 0x1f, 0xf3, 0xf6, 0xe8, 0xec, 0x69, 0x74, 0xcc, 0x59, 
                          0x68, 0xbf, 0xfa, 0x24, 0xd4, 0x79, 0x2, 0xab, 0x2, 0xe5, 0xb2, 0x72, 0x34, 0xc3, 0x99, 0x5d, 0xe4, 0xb3, 0x65, 0x61, 
                          0x6b, 0xa6, 0xd2, 0x3a, 0x76, 0xaf, 0x9e, 0x48, 0xe8, 0xb5, 0x66, 0x5d, 0xe5, 0x31, 0x46, 0x33, 0xbb, 0x2d, 0xcb, 0xe5, 
                          0xd1, 0x4c, 0x34, 0x32, 0xfb, 0x8a, 0x6, 0xe2, 0xea, 0x98, 0x2a, 0x4f, 0xe0, 0x55, 0x2, 0xb3, 0x65, 0x65, 0x8d, 0x91, 
                          0xcb, 0x47, 0x2e, 0xd2, 0x68, 0x68, 0x44, 0xc1, 0x67, 0xc7, 0x5c, 0x9d, 0x71, 0xf5, 0x82, 0x75, 0x65, 0x69, 0x38, 0x9a, 
                          0x55, 0xcd, 0xda, 0x6b, 0x46, 0x16, 0x1d, 0x79, 0xe5, 0x8, 0x4c, 0x4, 0x56, 0x82, 0x6c, 0x74, 0x1f, 0x69, 0xcb, 0x6c, 
                          0xac, 0x75, 0x21, 0x6f, 0xad, 0xa7, 0xae, 0xeb, 0x88, 0x7e, 0xb5, 0x82, 0x38, 0x32, 0x2b, 0x8c, 0x4, 0xb8, 0x10, 0x73, 
                          0x69, 0x12, 0x38, 0x58, 0xa0, 0x5e, 0xde, 0xad, 0x5c, 0x88, 0xbd, 0x19, 0xda, 0xca, 0xac, 0xa6, 0xb5, 0xf4, 0x6b, 0x75, 
                          0x31, 0xba, 0xec, 0xad, 0x97, 0x88, 0x2b, 0xfb, 0x45, 0x82, 0xaa, 0xe7, 0xd5, 0x9a, 0xbd, 0xb6, 0x2, 0xb5, 0xb5, 0x1c, 
                          0xb5, 0xc4, 0x3c, 0xf8, 0xa4, 0x56, 0x1d, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 
                          0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 
                          0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 
                          0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 
                          0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 
                          0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 
                          0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 
                          0xe0, 0x74, 0x81, 0x6f, 0xfc, 0x1f, 0xaa, 0x5b, 0xff, 0xa7, 0xec, 0x33, 0x3a, 0x7a, 0x64, 0xdf, 0x46, 0x75, 0x6d, 0x3d, 
                          0xce, 0xa7, 0xf7, 0x3b, 0xc3, 0x58, 0x9d, 0x4, 0x3e, 0x2e, 0xd0, 0xba, 0x70, 0xb6, 0x5e, 0x4c, 0x5b, 0x1b, 0xff, 0xc9, 
                          0xe3, 0x1d, 0x79, 0x2c, 0x41, 0xf6, 0xcb, 0x88, 0x1f, 0x69, 0xba, 0xf5, 0x1c, 0xb2, 0xdf, 0xcb, 0x5, 0xde, 0x14, 0x64, 
                          0x47, 0x5e, 0x70, 0x57, 0xa, 0xb1, 0x6f, 0x87, 0xc9, 0x91, 0xae, 0x2f, 0xbf, 0x1c, 0x75, 0x3f, 0x9f, 0xcc, 0xad, 0x25, 
                          0x5a, 0x7d, 0xa2, 0xe5, 0x9f, 0x73, 0xd9, 0x72, 0x7b, 0xbd, 0xad, 0x96, 0x6d, 0xed, 0x53, 0x5e, 0x48, 0xb3, 0xb, 0xbc, 
                          0x6e, 0x5f, 0xaf, 0xbe, 0x2d, 0xc7, 0xad, 0xfb, 0xb1, 0xd2, 0xef, 0x7c, 0xbc, 0x51, 0x7b, 0xca, 0xb6, 0xb7, 0xea, 0x2e, 
                          0xed, 0xca, 0xf6, 0x6f, 0xad, 0x73, 0xaf, 0xc1, 0xac, 0x4f, 0xad, 0xf6, 0x46, 0xda, 0xda, 0x72, 0xee, 0x79, 0x8c, 0xc6, 
                          0xc0, 0x55, 0x4b, 0xe0, 0x37, 0x2, 0xbd, 0x13, 0xa6, 0xf5, 0xdb, 0xba, 0x15, 0x5c, 0xf5, 0x49, 0x5f, 0xfe, 0xdc, 0xfa, 
                          0x77, 0x5d, 0x6f, 0x2b, 0x40, 0xeb, 0x8b, 0xb9, 0xf7, 0xf3, 0xec, 0x37, 0xfa, 0xac, 0x6f, 0xa3, 0x0, 0x8b, 0x86, 0xdb, 
                          0x8a, 0x53, 0x2b, 0x8c, 0x23, 0x7e, 0x2d, 0xb3, 0xde, 0x7e, 0xad, 0x10, 0x1b, 0xf9, 0xf5, 0xc6, 0x74, 0xd5, 0x2e, 0x3a, 
                          0x46, 0xb3, 0x73, 0x28, 0xda, 0x56, 0x97, 0x32, 0x81, 0xa1, 0x40, 0xf4, 0x44, 0x1b, 0x9d, 0xe8, 0xb3, 0x99, 0xd6, 0xe8, 
                          0x18, 0xa3, 0x10, 0x1b, 0x5d, 0xd0, 0xb3, 0xb, 0x78, 0xb6, 0xef, 0xec, 0xc2, 0xed, 0xd5, 0xdf, 0xa, 0xd3, 0xde, 0xc, 
                          0x2b, 0xea, 0xb2, 0xb5, 0xce, 0x88, 0x41, 0xf4, 0x97, 0xc4, 0xa8, 0xae, 0xe8, 0x2f, 0x90, 0x68, 0xb9, 0xd6, 0x2f, 0x83, 
                          0xd9, 0x78, 0xb9, 0x8c, 0x9, 0xfc, 0x4a, 0xa0, 0x5c, 0x12, 0x8c, 0x66, 0xc, 0xd1, 0x8b, 0xb0, 0x9e, 0x85, 0x8d, 0x2e, 
                          0xca, 0xde, 0x9, 0x5c, 0xd7, 0x11, 0xfd, 0x6d, 0x5f, 0x97, 0xdb, 0xd2, 0xb7, 0xd6, 0xb1, 0x67, 0xc1, 0xd2, 0x3b, 0xce, 
                          0x6c, 0xbf, 0x51, 0x38, 0x6e, 0xa9, 0xf3, 0xc8, 0x20, 0x5b, 0xb5, 0xab, 0xcb, 0xaf, 0x8e, 0x6d, 0xeb, 0x78, 0xd1, 0x5f, 
                          0x78, 0x2e, 0xe9, 0x97, 0xb, 0xac, 0xcc, 0x42, 0xa2, 0x33, 0xb5, 0xc8, 0x6f, 0xd2, 0xd1, 0x8c, 0x25, 0x3a, 0x23, 0x5b, 
                          0xf9, 0x6d, 0x3f, 0xbb, 0xc0, 0x57, 0x1c, 0x22, 0x41, 0xdd, 0xb, 0xe2, 0xa8, 0xe1, 0xa8, 0x6f, 0xb3, 0x99, 0xf0, 0xcc, 
                          0xef, 0xe8, 0xb6, 0x6d, 0xb1, 0x6b, 0x85, 0xdc, 0x4a, 0x9f, 0x5f, 0x7e, 0xd9, 0xea, 0xfe, 0xca, 0x5, 0x5d, 0x5f, 0x74, 
                          0xd1, 0x8b, 0x70, 0x16, 0x64, 0x2b, 0xbf, 0x65, 0xb7, 0x5e, 0x24, 0xb3, 0xb, 0x65, 0x16, 0x6, 0xa3, 0xbe, 0x6f, 0xed, 
                          0xdf, 0x68, 0xb6, 0x1b, 0x9d, 0x9, 0xb7, 0x8e, 0xbd, 0x12, 0x0, 0xd1, 0x31, 0x5c, 0x71, 0xdf, 0x5a, 0x76, 0x75, 0xc, 
                          0x5c, 0xbd, 0x4, 0x86, 0x2, 0xad, 0x25, 0x41, 0xf9, 0x5b, 0xbb, 0x35, 0x7b, 0x5a, 0xb9, 0xf0, 0xf2, 0xc5, 0x57, 0xef, 
                          0x33, 0x5b, 0x7a, 0xd4, 0x6d, 0x98, 0x9d, 0xf8, 0xad, 0x4e, 0x96, 0x7d, 0x1b, 0xcd, 0x54, 0x22, 0x17, 0x63, 0xaf, 0xae, 
                          0x51, 0xff, 0xca, 0x6d, 0xbd, 0x70, 0xed, 0xcd, 0x4e, 0x23, 0xc7, 0x8b, 0x18, 0xee, 0x31, 0x68, 0xed, 0xdb, 0xa, 0xce, 
                          0xc8, 0x39, 0xd4, 0x32, 0xee, 0xbd, 0xb6, 0x65, 0xac, 0x5d, 0xe6, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 
                          0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 
                          0x10, 0x20, 0x40, 0x80, 0xc0, 0x25, 0x5, 0x46, 0xcf, 0x68, 0x95, 0xd, 0x8e, 0x96, 0xbb, 0x64, 0x27, 0x35, 0x8a, 0x0, 
                          0x81, 0x67, 0xb, 0x44, 0x3, 0x2a, 0x5a, 0x2e, 0x6b, 0xcd, 0x1e, 0xb8, 0x7d, 0xb6, 0xaa, 0xde, 0x11, 0x20, 0xf0, 0x71, 
                          0x81, 0x51, 0xe8, 0xd4, 0xf, 0x82, 0x96, 0xf, 0xfd, 0xb6, 0x1e, 0x0, 0xae, 0x83, 0x6c, 0xf4, 0xa4, 0xfd, 0xc7, 0x3b, 
                          0xea, 0x80, 0x4, 0x8, 0x3c, 0x57, 0x60, 0xf4, 0x84, 0x7d, 0x6b, 0x86, 0x55, 0x4b, 0xf4, 0x3e, 0xd1, 0xd0, 0x7b, 0x42, 
                          0xfe, 0xb9, 0x92, 0x7a, 0x46, 0x80, 0xc0, 0x47, 0x5, 0xea, 0xf0, 0x9a, 0x2d, 0x1d, 0x67, 0xdb, 0x23, 0xe1, 0x96, 0xca, 
                          0xac, 0xd6, 0xf3, 0x51, 0x14, 0x7, 0x23, 0x40, 0xe0, 0xfe, 0x2, 0xa3, 0x90, 0xe9, 0x6d, 0x3b, 0xea, 0xf5, 0xfb, 0xeb, 
                          0xe9, 0x1, 0x1, 0x2, 0x97, 0x11, 0x58, 0x5d, 0xe, 0xa, 0xb2, 0xcb, 0xc, 0x9d, 0x86, 0x10, 0x78, 0xaf, 0xc0, 0xe8, 
                          0x66, 0x7e, 0xf4, 0xfe, 0x58, 0x4b, 0x6f, 0x35, 0xe0, 0xde, 0x3b, 0x2, 0x7a, 0x4e, 0x80, 0xc0, 0x2e, 0x81, 0xe8, 0x52, 
                          0xb2, 0xf5, 0xae, 0xe6, 0xec, 0xd, 0x2, 0x41, 0xb6, 0x6b, 0x68, 0xec, 0x4c, 0x80, 0x40, 0x44, 0x20, 0x7a, 0xd3, 0x7d, 
                          0xf6, 0xf8, 0xc4, 0xe8, 0x11, 0x8c, 0x95, 0x99, 0x5a, 0xa4, 0xcd, 0xca, 0x10, 0x20, 0x40, 0xe0, 0x57, 0x2, 0x47, 0x6, 
                          0x59, 0xaa, 0x78, 0x4b, 0x7d, 0x86, 0x84, 0x0, 0x1, 0x2, 0xbb, 0x5, 0xa2, 0xe1, 0x33, 0xba, 0x57, 0xb6, 0x52, 0xc7, 
                          0x4a, 0xd9, 0xdd, 0x9d, 0x53, 0x1, 0x1, 0x2, 0xef, 0x11, 0x68, 0xdd, 0xec, 0x1f, 0xf5, 0xbe, 0x2e, 0x3f, 0x93, 0x9a, 
                          0xdd, 0x4b, 0x9b, 0xed, 0x6f, 0x3b, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 
                          0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 
                          0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 
                          0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 
                          0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 
                          0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 
                          0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x38, 0x44, 0xa0, 
                          0xfc, 0xbf, 0x85, 0xfb, 0x3f, 0x87, 0x1f, 0x42, 0xaa, 0x12, 0x2, 0x4, 0x8e, 0x14, 0x58, 0xd, 0xa6, 0xd5, 0xf2, 0xb9, 
                          0xad, 0x5b, 0xf7, 0x3b, 0xb2, 0xaf, 0xea, 0x22, 0x40, 0xe0, 0xa1, 0x2, 0x2b, 0x1, 0xb3, 0x52, 0xb6, 0xe6, 0xda, 0xb3, 
                          0xef, 0x43, 0xe9, 0x75, 0x8b, 0xc0, 0x7b, 0x5, 0x52, 0x20, 0xe4, 0xbf, 0xad, 0xb0, 0x68, 0x6d, 0xcb, 0x21, 0x52, 0x6f, 
                          0x6b, 0xd5, 0x55, 0x96, 0x4d, 0xf5, 0xb7, 0x96, 0x95, 0xbd, 0x36, 0xd4, 0x61, 0x55, 0x1f, 0xb7, 0xb5, 0x7d, 0xd6, 0xde, 
                          0x72, 0x46, 0xd7, 0xeb, 0xf7, 0x7b, 0xcf, 0x6, 0x3d, 0x27, 0x70, 0x43, 0x81, 0x5e, 0x50, 0xd4, 0x81, 0xd3, 0xa, 0xa0, 
                          0xde, 0x7d, 0xae, 0x5e, 0xb8, 0xb4, 0x96, 0x84, 0xa3, 0xd0, 0x89, 0xb4, 0xa1, 0x24, 0x9f, 0xf5, 0x65, 0x74, 0x5f, 0xce, 
                          0xec, 0xee, 0x86, 0x27, 0xaf, 0x26, 0x13, 0x68, 0x85, 0xc4, 0x28, 0x14, 0x7a, 0x33, 0xa9, 0x5e, 0x38, 0xad, 0x4, 0xcc, 
                          0x68, 0xc9, 0x38, 0xb, 0xa7, 0xd6, 0xf1, 0xa3, 0x6d, 0x12, 0x5e, 0xae, 0x3, 0x2, 0xf, 0x10, 0x18, 0x5d, 0xc8, 0xad, 
                          0x6d, 0x91, 0x19, 0xcd, 0x6c, 0xbf, 0x59, 0x20, 0xce, 0xb6, 0xd7, 0xcb, 0xd4, 0xad, 0x41, 0x66, 0x79, 0xf9, 0x80, 0x13, 
                          0x58, 0x17, 0x8, 0xec, 0x99, 0x91, 0x8d, 0xc2, 0x6a, 0x34, 0x83, 0x9a, 0x85, 0x54, 0x1d, 0x4a, 0xd1, 0xd9, 0x58, 0xaf, 
                          0x2f, 0x5b, 0x43, 0xcf, 0xd9, 0x41, 0x80, 0xc0, 0x8d, 0x4, 0xb6, 0x6, 0xc5, 0xd6, 0xfd, 0x5a, 0x41, 0x16, 0xad, 0xab, 
                          0xf5, 0xa6, 0xc2, 0xd6, 0xe5, 0x6b, 0x64, 0xd6, 0x78, 0xa3, 0x61, 0xd4, 0x54, 0x2, 0x4, 0x7a, 0xef, 0x16, 0xe6, 0xd0, 
                          0x99, 0xdd, 0x8c, 0x9f, 0x85, 0x53, 0x24, 0xa8, 0x22, 0x6d, 0x98, 0x1d, 0x67, 0xa5, 0xbd, 0x75, 0x59, 0xf7, 0xca, 0x5c, 
                          0x7, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 
                          0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 
                          0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 
                          0x80, 0xc0, 0x19, 0x2, 0xad, 0xcf, 0x50, 0xf6, 0x3e, 0x7b, 0x59, 0x7e, 0x53, 0x45, 0xfd, 0x75, 0x41, 0x3e, 0xb, 0x79, 
                          0xc6, 0xe8, 0xa8, 0x93, 0x0, 0x81, 0xa9, 0xc0, 0x2c, 0xb0, 0x72, 0x5, 0xd1, 0x0, 0x13, 0x66, 0x53, 0x72, 0x5, 0x8, 
                          0x10, 0x38, 0x5a, 0x20, 0xfa, 0xad, 0x17, 0x75, 0xa0, 0x45, 0x7f, 0x3e, 0xba, 0xbd, 0xea, 0x23, 0x40, 0x80, 0xc0, 0x6f, 
                          0x4, 0xca, 0x65, 0x65, 0xef, 0xbb, 0xc4, 0x22, 0xdf, 0x38, 0xdb, 0xb, 0x36, 0xe4, 0x4, 0x8, 0x10, 0x38, 0x5d, 0x20, 
                          0xf2, 0x35, 0xda, 0x82, 0xec, 0xf4, 0x61, 0x70, 0x0, 0x2, 0x4, 0xf6, 0x8, 0xac, 0x7c, 0xe5, 0x75, 0x3a, 0xce, 0x6a, 
                          0xf9, 0x3d, 0x6d, 0xb3, 0x2f, 0x1, 0x2, 0x4, 0xc2, 0x2, 0xb3, 0x6f, 0x7e, 0x2d, 0x2b, 0x12, 0x64, 0x61, 0x56, 0x5, 
                          0x9, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 
                          0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0xf8, 0xcd, 0xa3, 0x12, 0x99, 0xa4, 0xf5, 0xff, 0xc0, 0xac, 0xb9, 
                          0x66, 0x1f, 0x35, 0x8a, 0x3e, 0x7f, 0xd6, 0x7a, 0xe0, 0x36, 0x72, 0x7c, 0xc3, 0x47, 0x80, 0x0, 0x81, 0xff, 0x84, 0x58, 
                          0xe4, 0x23, 0x48, 0x2d, 0xae, 0x23, 0x82, 0xac, 0xac, 0x77, 0x56, 0x9f, 0x21, 0x23, 0x40, 0x80, 0xc0, 0xaf, 0x4, 0xa2, 
                          0x1f, 0x4, 0x4f, 0x3b, 0xb5, 0xca, 0xd6, 0xb3, 0xa8, 0x5c, 0xae, 0x37, 0xbb, 0x1a, 0x5, 0x56, 0x64, 0x1f, 0xc3, 0x47, 
                          0x80, 0x0, 0x81, 0xdf, 0x8, 0xf4, 0x82, 0xa8, 0x47, 0xd5, 0x9a, 0x2d, 0xcd, 0x66, 0x50, 0xbd, 0xed, 0xb3, 0x7, 0x66, 
                          0x5b, 0xe1, 0x69, 0x8, 0x9, 0x10, 0x20, 0xd0, 0x15, 0xe8, 0x5, 0xd4, 0xe8, 0x49, 0xfe, 0xf2, 0x3e, 0xda, 0x88, 0x76, 
                          0x54, 0xf7, 0x6c, 0x6, 0x17, 0x39, 0xbe, 0x61, 0x25, 0x40, 0x80, 0xc0, 0xbf, 0x5, 0x66, 0xb3, 0xaa, 0xd1, 0xc, 0x6d, 
                          0x76, 0x43, 0x7e, 0x36, 0x23, 0x8b, 0xcc, 0xf2, 0xb6, 0xb6, 0xcf, 0xf0, 0x12, 0x20, 0xf0, 0x2, 0x81, 0xd6, 0x7d, 0xa9, 
                          0x95, 0x6e, 0x97, 0x21, 0x96, 0xc3, 0x26, 0xb2, 0x64, 0xac, 0xc3, 0xb3, 0xb5, 0x6f, 0xaf, 0xbe, 0x95, 0xf6, 0x29, 0x4b, 
                          0x80, 0xc0, 0x8b, 0x4, 0x22, 0x37, 0xf2, 0xb7, 0xbe, 0x31, 0xb0, 0x32, 0x23, 0x6b, 0xdd, 0xb3, 0xdb, 0x33, 0x63, 0x7c, 
                          0xd1, 0x10, 0xea, 0x2a, 0x81, 0xf7, 0xa, 0xd4, 0xb3, 0x9e, 0xd1, 0x6c, 0xea, 0xac, 0x20, 0x2b, 0xf5, 0x2d, 0x21, 0xdf, 
                          0x7b, 0x2e, 0xea, 0x39, 0x81, 0xcd, 0x2, 0x7b, 0x82, 0x6c, 0xcf, 0xcd, 0xfe, 0xd6, 0x2c, 0xcb, 0xe3, 0x17, 0x9b, 0x87, 
                          0xd1, 0x8e, 0x4, 0xde, 0x2d, 0x30, 0xbb, 0xf, 0x55, 0xce, 0x90, 0x66, 0x4b, 0xc4, 0xd1, 0x1b, 0x2, 0xad, 0x6d, 0xad, 
                          0xba, 0xa3, 0xf7, 0xd7, 0xde, 0x3d, 0x6a, 0x7a, 0x4f, 0x80, 0x40, 0x53, 0xa0, 0xf7, 0x98, 0x43, 0x19, 0x74, 0x67, 0x6, 
                          0x59, 0xbd, 0xbc, 0x9c, 0xbd, 0x13, 0x6a, 0x18, 0x9, 0x10, 0x20, 0xf0, 0x1f, 0x81, 0xd9, 0x73, 0x5a, 0x91, 0x7b, 0x56, 
                          0xa3, 0x32, 0xa3, 0x40, 0xaa, 0x67, 0x64, 0xad, 0xb2, 0xb3, 0xf6, 0x19, 0x4a, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 
                          0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 
                          0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0xc0, 0x7, 0x5, 0x7a, 0x4f, 0xce, 0x8f, 0x9e, 0xf, 0x6b, 0xed, 0xd3, 0x6a, 
                          0xf2, 0x4a, 0xdd, 0x9e, 0xe0, 0xff, 0xe0, 0xa0, 0x3b, 0x14, 0x81, 0x37, 0x8, 0x44, 0x9e, 0x13, 0x2b, 0x1d, 0x56, 0xca, 
                          0x1f, 0x51, 0x56, 0xe8, 0xbd, 0xe1, 0x2c, 0xd4, 0x47, 0x2, 0x3b, 0x4, 0x56, 0x82, 0x26, 0x1d, 0x66, 0xa5, 0xfc, 0x51, 
                          0x65, 0xb7, 0x7e, 0x9a, 0x60, 0x7, 0x8b, 0x5d, 0x9, 0x10, 0xb8, 0x8b, 0xc0, 0x4a, 0xd0, 0x7c, 0x2b, 0xc4, 0x46, 0xc7, 
                          0x5d, 0x6d, 0xff, 0x5d, 0xc6, 0x45, 0x3b, 0x9, 0x10, 0x8, 0xa, 0xac, 0x86, 0x40, 0xbd, 0xbc, 0x1b, 0x1d, 0x66, 0xa5, 
                          0xee, 0x48, 0xbd, 0x66, 0x64, 0xc1, 0x41, 0x55, 0x8c, 0xc0, 0x1b, 0x4, 0x46, 0x37, 0xe3, 0xa3, 0x9f, 0x87, 0xcc, 0x4e, 
                          0x75, 0xb8, 0x6c, 0xa9, 0xbb, 0x15, 0x50, 0xd1, 0xd7, 0x56, 0x67, 0x88, 0x6f, 0x18, 0x5f, 0x7d, 0x24, 0xf0, 0x4a, 0x81, 
                          0x51, 0x78, 0xf5, 0x2, 0x2b, 0x7a, 0xd3, 0x7f, 0x56, 0xf7, 0x68, 0xd6, 0x16, 0xd, 0xc9, 0x57, 0xe, 0x9a, 0x4e, 0x13, 
                          0x20, 0xf0, 0x5f, 0x81, 0xc8, 0xf2, 0x6f, 0x56, 0x66, 0xeb, 0x92, 0x6f, 0xb5, 0xde, 0x59, 0x79, 0xe3, 0x4a, 0x80, 0xc0, 
                          0xb, 0x5, 0x8e, 0xa, 0x86, 0x95, 0x65, 0xe0, 0xa, 0x73, 0x6b, 0x46, 0xb6, 0xb2, 0xbf, 0xb2, 0x4, 0x8, 0xbc, 0x40, 
                          0x40, 0x90, 0xbd, 0x60, 0x90, 0x75, 0x91, 0xc0, 0xd3, 0x5, 0xf6, 0x6, 0xd9, 0xea, 0x1b, 0x3, 0x51, 0xcf, 0x5e, 0xbd, 
                          0x7b, 0xdb, 0x1b, 0x3d, 0xbe, 0x72, 0x4, 0x8, 0xdc, 0x4c, 0xa0, 0xf5, 0x2e, 0x63, 0xaf, 0xb, 0x91, 0x47, 0x24, 0xea, 
                          0x37, 0x1, 0x22, 0xfb, 0x44, 0xca, 0xdc, 0x8c, 0x55, 0x73, 0x9, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 
                          0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0xd8, 
                          0x2c, 0x30, 0x7a, 0xb8, 0xd5, 0x3, 0xaa, 0x9b, 0x59, 0xed, 0x48, 0x80, 0xc0, 0x11, 0x2, 0xd1, 0x67, 0xb0, 0x4, 0xd9, 
                          0x11, 0xda, 0xea, 0x20, 0x40, 0xe0, 0x10, 0x81, 0xad, 0xb3, 0xa7, 0x95, 0xfd, 0xca, 0xb2, 0xe5, 0xb3, 0x60, 0x2b, 0x1d, 
                          0xd8, 0x13, 0xb0, 0xf5, 0x71, 0x3c, 0x8f, 0xb6, 0x22, 0xaf, 0x2c, 0x81, 0x1b, 0x8, 0xe4, 0x80, 0x58, 0x79, 0xe0, 0x35, 
                          0x75, 0xab, 0x15, 0x48, 0xa3, 0x6f, 0xa1, 0xc8, 0xfb, 0x94, 0x24, 0xb3, 0x70, 0x8a, 0x6, 0x4e, 0xb4, 0x5c, 0xab, 0xd, 
                          0xbd, 0xd7, 0x6e, 0x30, 0x74, 0x9a, 0x48, 0x80, 0x40, 0x16, 0xa8, 0x3f, 0xe6, 0x53, 0xcf, 0x9e, 0xea, 0xe0, 0x19, 0x5, 
                          0x58, 0x2f, 0x98, 0x8e, 0xf8, 0x88, 0xd2, 0x2c, 0xf4, 0xca, 0xfe, 0xf4, 0x46, 0x77, 0x54, 0x47, 0xb4, 0x7e, 0x67, 0xe, 
                          0x1, 0x2, 0x17, 0x14, 0x98, 0x2d, 0x11, 0x47, 0xf7, 0xc2, 0x5a, 0xe1, 0x11, 0x29, 0xbf, 0x32, 0x2b, 0x8b, 0x4, 0x54, 
                          0xb4, 0x3e, 0x41, 0x76, 0xc1, 0x13, 0x50, 0x93, 0x8, 0x1c, 0x21, 0x20, 0xc8, 0x7e, 0x51, 0x34, 0x23, 0x3b, 0xe2, 0x6c, 
                          0x52, 0x7, 0x81, 0x2f, 0x8, 0x94, 0xf7, 0xc7, 0xa2, 0xf7, 0x8f, 0x66, 0x33, 0xae, 0xde, 0x7d, 0xb2, 0x2d, 0xcb, 0xbd, 
                          0xe8, 0x4c, 0x2b, 0x5a, 0xce, 0x8c, 0xec, 0xb, 0x27, 0x99, 0x43, 0x12, 0x38, 0x5b, 0x40, 0x90, 0xfd, 0x57, 0xd8, 0x8c, 
                          0xec, 0xec, 0xb3, 0x4d, 0xfd, 0x4, 0x4e, 0x12, 0x18, 0xdd, 0xd8, 0xef, 0xdd, 0x9b, 0x9a, 0xcd, 0xc8, 0x5a, 0xb3, 0xa3, 
                          0xd1, 0xbb, 0x99, 0xd1, 0x0, 0x39, 0xa2, 0x9c, 0x19, 0xd9, 0x49, 0x27, 0x92, 0x6a, 0x9, 0x7c, 0x53, 0xa0, 0xe, 0xb2, 
                          0x59, 0x48, 0x8d, 0xde, 0x95, 0x6c, 0xf5, 0xa3, 0x9e, 0xf1, 0xb5, 0x96, 0xaf, 0xa3, 0x77, 0x34, 0xa3, 0x4b, 0xc6, 0x95, 
                          0x72, 0xb3, 0x3e, 0x7e, 0x73, 0x3c, 0x1c, 0x9b, 0x0, 0x81, 0xd, 0x2, 0xb3, 0xa5, 0xe5, 0xe8, 0x8d, 0x80, 0xc8, 0x6c, 
                          0xae, 0x35, 0xab, 0x9b, 0xbd, 0xb9, 0xf0, 0x89, 0x7b, 0x69, 0x39, 0x3c, 0xa3, 0x21, 0xba, 0x81, 0xd6, 0x2e, 0x4, 0x8, 
                          0x7c, 0x52, 0xa0, 0x37, 0x43, 0x89, 0x2c, 0xe5, 0xa2, 0x41, 0x30, 0x5a, 0x5a, 0x7e, 0xb2, 0xaf, 0x8e, 0x45, 0x80, 0x0, 
                          0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 
                          0x4, 0x8, 0xec, 0x10, 0x88, 0xbc, 0x79, 0xd0, 0x7a, 0x97, 0xb3, 0xf5, 0xda, 0x4a, 0x5d, 0x3b, 0x9a, 0x6c, 0x57, 0x2, 
                          0x4, 0x8, 0xfc, 0x5a, 0x20, 0x1a, 0x3e, 0x91, 0x67, 0xd5, 0xa2, 0x75, 0x19, 0x3, 0x2, 0x4, 0x8, 0x1c, 0x2a, 0x10, 
                          0x9, 0x9f, 0xde, 0xb3, 0x69, 0x1e, 0x62, 0x3d, 0x74, 0x28, 0x54, 0x46, 0x80, 0xc0, 0x56, 0x81, 0x48, 0x90, 0xa5, 0xba, 
                          0x47, 0xf, 0xe9, 0x6e, 0x7d, 0x98, 0x76, 0x6b, 0x9b, 0xed, 0x47, 0x80, 0x0, 0x81, 0x5f, 0x9, 0x44, 0x83, 0xac, 0xc, 
                          0xb3, 0x9a, 0x70, 0xa5, 0xe, 0xfc, 0x4, 0x8, 0x10, 0x38, 0x5c, 0xa0, 0xfe, 0x58, 0x50, 0xef, 0x53, 0x1, 0x91, 0xe5, 
                          0xa5, 0x40, 0x3b, 0x7c, 0x78, 0x54, 0x48, 0x80, 0x40, 0x44, 0x20, 0x12, 0x3e, 0xad, 0xb0, 0xcb, 0x33, 0xb4, 0x72, 0xdb, 
                          0x68, 0xd6, 0x16, 0x69, 0x8b, 0x32, 0x4, 0x8, 0x10, 0xd8, 0x24, 0x10, 0x9, 0xb2, 0x5c, 0xf1, 0x4a, 0xd9, 0x4d, 0x8d, 
                          0xb1, 0x13, 0x1, 0x2, 0x4, 0xb6, 0x8, 0xac, 0x84, 0xd3, 0xe8, 0x5d, 0xca, 0x95, 0x7a, 0xb6, 0xb4, 0xd3, 0x3e, 0x4, 
                          0x8, 0x10, 0xe8, 0xa, 0x44, 0x2, 0x28, 0xf2, 0x8e, 0x65, 0x5d, 0x6, 0x39, 0x1, 0x2, 0x4, 0x3e, 0x26, 0xb0, 0x25, 
                          0xc8, 0xca, 0x7b, 0x61, 0x9e, 0x25, 0xfb, 0xd8, 0x50, 0x39, 0x10, 0x1, 0x2, 0x3d, 0x81, 0x23, 0x83, 0xcc, 0xac, 0xcc, 
                          0x79, 0x46, 0x80, 0xc0, 0xa9, 0x2, 0xbd, 0xc7, 0x2c, 0x46, 0xaf, 0xd7, 0xd, 0x6a, 0x5, 0x55, 0xbd, 0xff, 0xa9, 0x9d, 
                          0x50, 0x39, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 
                          0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 
                          0x4, 0x8, 0x84, 0x4, 0x7a, 0xf, 0xb9, 0xf6, 0x9e, 0xc2, 0xaf, 0xbf, 0xc1, 0xa2, 0x3c, 0x48, 0xef, 0xeb, 0x7b, 0xea, 
                          0x86, 0x94, 0xcf, 0x98, 0x45, 0xbf, 0x1a, 0x28, 0xd4, 0x19, 0x85, 0x8, 0x10, 0x78, 0xa7, 0x40, 0xe4, 0x3b, 0xc5, 0x92, 
                          0x4c, 0xe4, 0xe3, 0x45, 0x91, 0x20, 0x8b, 0x94, 0x79, 0xe7, 0x48, 0xe8, 0x35, 0x1, 0x2, 0x9b, 0x5, 0x7a, 0x1f, 0x15, 
                          0x8a, 0x6, 0x4e, 0xaf, 0xdc, 0x6a, 0xf0, 0x6d, 0xee, 0x80, 0x1d, 0x9, 0x10, 0x20, 0xf0, 0xa9, 0x20, 0x8b, 0x4, 0x9b, 
                          0xd1, 0x20, 0x40, 0x80, 0xc0, 0x26, 0x81, 0xc8, 0x8c, 0x6a, 0xf4, 0x61, 0xf1, 0x3d, 0xfb, 0xaf, 0x7c, 0x76, 0x73, 0x53, 
                          0xe7, 0xec, 0x44, 0x80, 0xc0, 0x3b, 0x4, 0xf6, 0x4, 0x51, 0x7d, 0xef, 0xac, 0x55, 0x57, 0xef, 0x1e, 0x5c, 0xef, 0xbe, 
                          0xdb, 0x3b, 0xd4, 0xf5, 0x92, 0x0, 0x81, 0x43, 0x5, 0xea, 0xd9, 0x56, 0xef, 0x5b, 0x2b, 0x7a, 0x7, 0x1d, 0x5, 0xe1, 
                          0xec, 0x3e, 0xdb, 0x68, 0xa6, 0x77, 0x68, 0x27, 0x55, 0x46, 0x80, 0xc0, 0xb3, 0x5, 0xce, 0xc, 0xb2, 0x5a, 0xae, 0x77, 
                          0xac, 0x67, 0xb, 0xeb, 0x1d, 0x1, 0x2, 0xa7, 0xb, 0x8c, 0x9e, 0x17, 0x2b, 0xf, 0x1e, 0xb9, 0x59, 0x3f, 0x9b, 0x81, 
                          0x8d, 0x96, 0xa2, 0xa7, 0x77, 0xd4, 0x1, 0x8, 0x10, 0x78, 0xae, 0x40, 0x6f, 0x79, 0x37, 0xa, 0xb8, 0xc8, 0xb3, 0x67, 
                          0x91, 0x37, 0x8, 0xdc, 0xec, 0x7f, 0xee, 0x79, 0xa5, 0x67, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 
                          0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 
                          0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 
                          0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 
                          0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 
                          0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 
                          0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 
                          0x40, 0x80, 0x0, 0x1, 0x2, 0xdf, 0x16, 0x18, 0xfd, 0x1f, 0xc7, 0xbf, 0xdd, 0x36, 0xc7, 0x27, 0x40, 0xe0, 0x66, 0x2, 
                          0xdf, 0xa, 0x94, 0xc8, 0x71, 0x23, 0x65, 0x6e, 0xc6, 0xad, 0xb9, 0x4, 0x8, 0x9c, 0x21, 0xf0, 0xad, 0xb0, 0x88, 0x1c, 
                          0x37, 0x52, 0xe6, 0xc, 0x13, 0x75, 0x12, 0x20, 0x70, 0x23, 0x81, 0x14, 0x14, 0xf9, 0x6f, 0x6e, 0x76, 0xe, 0x8f, 0x32, 
                          0x44, 0x5a, 0xe5, 0x52, 0xf9, 0xb2, 0x6c, 0x2b, 0x74, 0x66, 0xfb, 0x95, 0xc7, 0x6c, 0xb5, 0xa3, 0x7e, 0x2d, 0x1f, 0xb3, 
                          0xf7, 0x7a, 0xd9, 0xa6, 0x1b, 0xd, 0x83, 0xa6, 0x12, 0x20, 0xb0, 0x57, 0xa0, 0xe, 0xa0, 0x5e, 0xb0, 0xd5, 0x41, 0x57, 
                          0x86, 0x4a, 0x6f, 0x5b, 0xd9, 0xb6, 0x3a, 0x18, 0x5b, 0xfb, 0xd4, 0x41, 0xd4, 0x6a, 0xdb, 0xa8, 0x4e, 0x33, 0xb8, 0xbd, 
                          0x67, 0x83, 0xfd, 0x9, 0xdc, 0x54, 0x60, 0x16, 0x16, 0x75, 0xb7, 0x7a, 0x81, 0xd4, 0xa, 0xa1, 0x5e, 0xb0, 0x8c, 0x2, 
                          0x27, 0x1a, 0x78, 0xb3, 0xd0, 0xbb, 0xe9, 0x70, 0x68, 0x36, 0x1, 0x2, 0xab, 0x2, 0xbd, 0xe5, 0x60, 0x3d, 0xeb, 0x29, 
                          0x97, 0x88, 0xd1, 0x20, 0x9b, 0x2d, 0x1b, 0x5b, 0xdb, 0xcb, 0xd9, 0x60, 0x24, 0x60, 0x47, 0x6d, 0x59, 0xb5, 0x50, 0x9e, 
                          0x0, 0x81, 0x9b, 0xa, 0xcc, 0xc2, 0x62, 0xb4, 0x7d, 0x14, 0x82, 0xb3, 0x80, 0x6c, 0xdd, 0x87, 0x9b, 0xcd, 0xb0, 0x56, 
                          0x8f, 0x77, 0xd3, 0x21, 0xd1, 0x6c, 0x2, 0x4, 0x56, 0x5, 0x8e, 0xc, 0xb2, 0xd9, 0xec, 0xa8, 0x15, 0x5e, 0x2b, 0x41, 
                          0xb9, 0x52, 0x76, 0xd5, 0x41, 0x79, 0x2, 0x4, 0x6e, 0x2c, 0x30, 0xbb, 0xb1, 0x9f, 0x67, 0x49, 0xad, 0x77, 0x1f, 0x23, 
                          0x21, 0x18, 0xdd, 0xaf, 0x57, 0xae, 0xf7, 0x46, 0xc4, 0xec, 0xd8, 0x37, 0x1e, 0x12, 0x4d, 0x27, 0x40, 0x80, 0x0, 0x1, 
                          0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 
                          0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 
                          0x68, 0x9, 0xd4, 0x9f, 0x95, 0x6c, 0x3d, 0x80, 0x3a, 0x92, 0x3b, 0xea, 0x5b, 0x25, 0x8e, 0xaa, 0xc7, 0x28, 0x13, 0x20, 
                          0xf0, 0x42, 0x81, 0x3d, 0x1, 0xd2, 0xfb, 0x5c, 0xe4, 0x16, 0xc6, 0x3d, 0xed, 0xd8, 0x72, 0x3c, 0xfb, 0x10, 0x20, 0xf0, 
                          0x20, 0x81, 0x3d, 0x1, 0x22, 0xc8, 0x1e, 0x74, 0x22, 0xe8, 0xa, 0x81, 0x3b, 0xb, 0x9c, 0x11, 0x64, 0xb3, 0xf, 0x71, 
                          0xd7, 0x9f, 0xe3, 0x4c, 0x7e, 0xab, 0x9f, 0x9d, 0x6c, 0xd5, 0x91, 0xeb, 0xd9, 0xb2, 0xed, 0xce, 0x63, 0xa8, 0xed, 0x4, 
                          0x5e, 0x2f, 0xb0, 0xf5, 0x1e, 0xd9, 0x2c, 0xac, 0x4a, 0xd8, 0xd5, 0xaf, 0xe6, 0x99, 0xd5, 0xdd, 0xfb, 0x36, 0x8d, 0xd9, 
                          0x7e, 0xad, 0x36, 0xbd, 0xfe, 0x4, 0x0, 0x40, 0xe0, 0x9, 0x2, 0x5b, 0x67, 0x64, 0xb3, 0x6f, 0x99, 0x88, 0x2c, 0x3b, 
                          0x7b, 0x81, 0x54, 0xbb, 0x8e, 0xca, 0x6d, 0xa9, 0xa3, 0x35, 0x3, 0x7c, 0xc2, 0x58, 0xea, 0x3, 0x81, 0xd7, 0xa, 0xcc, 
                          0x82, 0x6c, 0xf4, 0x35, 0x3a, 0xad, 0xd9, 0x5c, 0x86, 0x1c, 0xcd, 0xc2, 0x7a, 0x75, 0xd6, 0x33, 0xa6, 0x68, 0xb9, 0xfa, 
                          0x98, 0xad, 0xc1, 0x1c, 0xb5, 0xf5, 0xb5, 0x83, 0xaf, 0xe3, 0x4, 0x9e, 0x22, 0x30, 0xb, 0xb2, 0x5e, 0x28, 0xcc, 0x5e, 
                          0x6f, 0x5, 0x59, 0x74, 0xe9, 0x17, 0x2d, 0x57, 0xcf, 0xac, 0x46, 0x7d, 0xd9, 0xd2, 0xcf, 0xa7, 0x8c, 0xb1, 0x7e, 0x10, 
                          0x78, 0xbc, 0xc0, 0xea, 0x5, 0x3e, 0x2b, 0xbf, 0xb2, 0xc, 0x8c, 0xdc, 0xeb, 0xaa, 0x6f, 0xdc, 0x1f, 0x15, 0x72, 0xb3, 
                          0x7e, 0x3c, 0x7e, 0xe0, 0x75, 0x90, 0xc0, 0x93, 0x4, 0x56, 0x6f, 0xf6, 0xcf, 0x2, 0x60, 0x76, 0xcf, 0xaa, 0xc, 0xa6, 
                          0x59, 0xe8, 0xad, 0xce, 0xea, 0xf2, 0xc, 0xad, 0xe, 0xbf, 0x72, 0xe9, 0xd9, 0xdb, 0xf6, 0xa4, 0x31, 0xd5, 0x17, 0x2, 
                          0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 
                          0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 
                          0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 
                          0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 
                          0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 
                          0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 
                          0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0xc0, 0x33, 0x4, 0x66, 0xff, 0x67, 0xed, 0x3b, 
                          0xf5, 0xf2, 0x49, 0x7d, 0xc9, 0xee, 0x4f, 0xec, 0xd3, 0x9d, 0xce, 0x29, 0x6d, 0xbd, 0x89, 0xc0, 0x93, 0x2e, 0x94, 0xbb, 
                          0xf7, 0xe5, 0xee, 0xed, 0xdf, 0x72, 0xca, 0xbf, 0xb1, 0xcf, 0x5b, 0x9c, 0xec, 0x33, 0x10, 0x78, 0xd2, 0x49, 0xf4, 0x84, 
                          0xbe, 0x3c, 0xa1, 0xf, 0xab, 0x17, 0xdc, 0x1b, 0xfb, 0xbc, 0x6a, 0xa4, 0xfc, 0x44, 0x20, 0x9f, 0x44, 0xe9, 0xbf, 0xf9, 
                          0x6f, 0xb9, 0x4b, 0x7d, 0x92, 0xb5, 0x7e, 0x2e, 0xeb, 0xa8, 0xf7, 0x6d, 0xd5, 0xd9, 0x6a, 0xd2, 0xec, 0xf8, 0xbd, 0x7a, 
                          0xca, 0xd7, 0x67, 0x17, 0xc4, 0xec, 0x18, 0xbd, 0xa5, 0xdc, 0xe8, 0x18, 0x91, 0x6d, 0xad, 0x76, 0xb5, 0xda, 0xd2, 0x7b, 
                          0x2d, 0x62, 0x5a, 0x8f, 0x63, 0x6d, 0xdc, 0xeb, 0x7b, 0xab, 0x5c, 0x7a, 0xad, 0x6c, 0xf3, 0xcc, 0x6d, 0x36, 0x36, 0xbd, 
                          0x73, 0xa8, 0xac, 0xb7, 0x77, 0x5e, 0x8d, 0xf6, 0x2d, 0xc7, 0x2b, 0x7a, 0x9e, 0x9, 0x84, 0x87, 0xa, 0xcc, 0xc2, 0x6b, 
                          0x14, 0x64, 0xad, 0x93, 0x7d, 0x14, 0x6, 0x3d, 0xc2, 0xd9, 0x31, 0xea, 0xe3, 0xb4, 0x8e, 0x31, 0x3b, 0x91, 0x67, 0xc7, 
                          0xe8, 0x85, 0x77, 0xb4, 0x8f, 0xf5, 0xf1, 0x8f, 0x38, 0x5e, 0x2b, 0x50, 0x46, 0xed, 0x8c, 0x38, 0xd5, 0x75, 0xf6, 0x2, 
                          0x2f, 0x32, 0x8e, 0xa3, 0x3e, 0xcf, 0xfa, 0xdf, 0x6b, 0x6b, 0xab, 0x7d, 0xd1, 0x31, 0x98, 0xf5, 0xed, 0xa1, 0x97, 0xb0, 
                          0x6e, 0xf5, 0x6, 0x3e, 0x72, 0x92, 0xf5, 0x66, 0x19, 0xf5, 0x6f, 0xc9, 0x2d, 0xca, 0x47, 0x1c, 0x7f, 0x76, 0x81, 0x46, 
                          0x66, 0x9d, 0xa3, 0x3e, 0x6e, 0xdd, 0x96, 0xcd, 0x5b, 0xfb, 0x8f, 0x2e, 0xe2, 0x88, 0x77, 0x34, 0xe4, 0x46, 0x63, 0x32, 
                          0xb2, 0x8f, 0x6, 0xeb, 0xde, 0xb6, 0xf6, 0x66, 0x89, 0x3d, 0x9f, 0x9e, 0xe5, 0x96, 0x73, 0xcf, 0x3e, 0x37, 0x15, 0xd8, 
                          0x7a, 0xd2, 0xcd, 0xf6, 0x5b, 0x99, 0xf6, 0xd7, 0x4b, 0x8c, 0x33, 0x82, 0x6c, 0xd4, 0x9e, 0xc8, 0xf2, 0xa5, 0x9e, 0xa1, 
                          0xcc, 0x82, 0x6c, 0xd4, 0xa7, 0x5e, 0x5b, 0x66, 0x75, 0xae, 0x5e, 0xe0, 0xbd, 0x30, 0x1f, 0x5d, 0xf8, 0xad, 0xd9, 0x4f, 
                          0xdd, 0x97, 0xd9, 0x2f, 0xc0, 0xd9, 0xb9, 0x31, 0x1b, 0xdf, 0x95, 0xf3, 0x61, 0xe5, 0x3c, 0xbb, 0xe9, 0x25, 0xaa, 0xd9, 
                          0x33, 0x81, 0xd9, 0xac, 0x60, 0xb6, 0x3c, 0x18, 0xcd, 0x0, 0x46, 0x17, 0x5d, 0x64, 0x36, 0xb4, 0x7a, 0xb1, 0x44, 0x2f, 
                          0xce, 0x59, 0x20, 0xcd, 0x2e, 0xb2, 0x7a, 0xff, 0xd6, 0xcf, 0x9f, 0x68, 0x4b, 0xe9, 0xb3, 0x27, 0x0, 0xa3, 0x63, 0x11, 
                          0x19, 0xcf, 0xdc, 0x8e, 0x95, 0xf6, 0x8c, 0xce, 0xb1, 0xd9, 0x31, 0x67, 0x81, 0x39, 0x3b, 0xff, 0x6d, 0x7f, 0x88, 0x40, 
                          0xfe, 0xcd, 0x17, 0x9, 0xa4, 0xba, 0xec, 0x4a, 0xc8, 0xf5, 0x42, 0xa9, 0xb7, 0x54, 0x58, 0xd, 0x8b, 0x56, 0x3f, 0x46, 
                          0x17, 0x68, 0x2f, 0x4, 0xf6, 0xf4, 0x71, 0x6b, 0x0, 0x8e, 0x2, 0x69, 0x6b, 0x9d, 0xa3, 0xfd, 0xb6, 0x8e, 0x45, 0xbd, 
                          0xdf, 0xc8, 0x6a, 0xe5, 0xdc, 0x98, 0x5, 0x59, 0xd4, 0xa0, 0x77, 0xce, 0x3c, 0xe4, 0x52, 0xd5, 0x8d, 0x91, 0x40, 0xf9, 
                          0x1b, 0xb4, 0x17, 0x6, 0xe5, 0xeb, 0xad, 0x93, 0xae, 0x5c, 0x6, 0xd4, 0xe1, 0xd1, 0xdb, 0xd6, 0xfa, 0x4d, 0xdb, 0x2a, 
                          0x1b, 0x39, 0xc9, 0x47, 0xb3, 0x80, 0x68, 0x7b, 0xce, 0xe8, 0xe3, 0xa8, 0xef, 0xe5, 0xb6, 0xfa, 0x42, 0x9d, 0x5d, 0xb8, 
                          0xb3, 0x5f, 0x3e, 0xbd, 0x5f, 0xe, 0x91, 0xb1, 0xe8, 0xcd, 0x70, 0x46, 0xc7, 0x9c, 0x9d, 0x37, 0x2b, 0x63, 0x58, 0x86, 
                          0x51, 0xa4, 0x9f, 0xb9, 0xaf, 0x91, 0xbe, 0x49, 0x2, 0x2, 0x21, 0x81, 0xd6, 0x45, 0x10, 0xda, 0xf1, 0x46, 0x85, 0x46, 
                          0x7d, 0x7c, 0x43, 0xff, 0xcd, 0x7a, 0x6e, 0x74, 0xb2, 0x6a, 0xea, 0x5c, 0x60, 0xf6, 0x5b, 0x76, 0x5e, 0xc3, 0xf5, 0x4b, 
                          0xec, 0x59, 0x1e, 0x5d, 0xbf, 0x77, 0xfb, 0x5a, 0xf8, 0xa6, 0xd0, 0xde, 0x27, 0x65, 0xef, 0xcb, 0xb, 0xf4, 0x96, 0x47, 
                          0x97, 0x6f, 0xf8, 0x42, 0x3, 0x47, 0x7d, 0x7c, 0x43, 0xff, 0x7b, 0x54, 0x82, 0x6c, 0xe1, 0x24, 0x52, 0x94, 0x0, 0x1, 
                          0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x81, 0x27, 0xb, 0xf4, 0xee, 0x81, 0x1d, 0xb9, 0x6c, 0x3a, 0xb2, 0xae, 
                          0x27, 0x8f, 0x85, 0xbe, 0x11, 0x20, 0xb0, 0x51, 0x60, 0x4b, 0x90, 0xad, 0x6, 0xd3, 0x6a, 0xf9, 0x48, 0x57, 0xce, 0xa8, 
                          0x33, 0x72, 0x5c, 0x65, 0x8, 0x10, 0xb8, 0x90, 0x40, 0x7d, 0x93, 0xbe, 0x7e, 0x6, 0xe9, 0xc8, 0x47, 0x2c, 0xce, 0x8, 
                          0x9d, 0x33, 0xea, 0xbc, 0xd0, 0xf0, 0x68, 0xa, 0x1, 0x2, 0x2b, 0x2, 0xab, 0x81, 0x10, 0x2d, 0x3f, 0xa, 0xca, 0xde, 
                          0x3, 0xa7, 0xa9, 0xdd, 0x91, 0xfa, 0x23, 0x65, 0x56, 0xc, 0x94, 0x25, 0x40, 0xe0, 0xe6, 0x2, 0xab, 0xa1, 0x70, 0x56, 
                          0xf9, 0xb2, 0xde, 0xd9, 0x31, 0x66, 0xdb, 0x6f, 0x3e, 0x24, 0x9a, 0x4f, 0x80, 0xc0, 0x8a, 0x40, 0x1d, 0x1e, 0x91, 0x67, 
                          0xc2, 0x56, 0x43, 0x64, 0xa5, 0x7c, 0x2e, 0x3b, 0x6b, 0xc7, 0x4a, 0x9d, 0x2b, 0x1e, 0xca, 0x12, 0x20, 0x70, 0x43, 0x81, 
                          0xd5, 0x40, 0xa8, 0x83, 0x26, 0xd2, 0xe5, 0x56, 0x38, 0xf5, 0xf6, 0xcb, 0x1, 0x56, 0x2f, 0x31, 0x5b, 0xb3, 0xb5, 0xb2, 
                          0x6c, 0xa4, 0x1d, 0xca, 0x10, 0x20, 0xf0, 0x50, 0x81, 0x2d, 0x41, 0x36, 0x5a, 0x2, 0xf6, 0xee, 0x7d, 0xd5, 0xaf, 0xb7, 
                          0x7e, 0xae, 0x83, 0xa9, 0x77, 0x9c, 0x51, 0xb9, 0xe8, 0x3d, 0xb6, 0x87, 0xe, 0xa7, 0x6e, 0x11, 0x78, 0xa7, 0xc0, 0x96, 
                          0x20, 0x2b, 0xa5, 0x22, 0x1, 0x35, 0x9a, 0x7d, 0xb5, 0xb6, 0x8d, 0xde, 0x8, 0x68, 0x5, 0xd5, 0xac, 0xd, 0xef, 0x1c, 
                          0x59, 0xbd, 0x26, 0xf0, 0x12, 0x81, 0xd5, 0x0, 0x98, 0x5, 0x4c, 0x24, 0x64, 0x46, 0x21, 0x98, 0xb7, 0x8d, 0x96, 0xa2, 
                          0x5b, 0xda, 0xf0, 0x92, 0xe1, 0xd4, 0x4d, 0x2, 0xef, 0x14, 0x58, 0x79, 0x97, 0xb0, 0xb7, 0x64, 0x5b, 0xd, 0xc3, 0x95, 
                          0x20, 0xdb, 0x32, 0x5b, 0xb3, 0xb4, 0x7c, 0xe7, 0xb9, 0xac, 0xd7, 0x2f, 0x16, 0x38, 0x3a, 0xc8, 0x56, 0x96, 0xa9, 0xb3, 
                          0xb2, 0xbd, 0xed, 0xb3, 0x19, 0xd9, 0xac, 0xde, 0x17, 0xf, 0xb7, 0xae, 0x13, 0x78, 0x87, 0x40, 0xfd, 0xc8, 0x43, 0x74, 
                          0xb6, 0x15, 0x7d, 0xf7, 0xb0, 0xac, 0x7f, 0x26, 0xba, 0x12, 0x64, 0x79, 0x16, 0x26, 0xc4, 0x66, 0xaa, 0xb6, 0x13, 0x20, 
                          0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 
                          0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x37, 0x12, 0x68, 0x3d, 0xca, 0x31, 0x7a, 0xed, 
                          0x46, 0x5d, 0xd3, 0x54, 0x2, 0x4, 0xde, 0x22, 0xe0, 0x99, 0xae, 0xb7, 0x8c, 0xb4, 0x7e, 0x12, 0x78, 0xb0, 0xc0, 0xea, 
                          0x3, 0xad, 0xf, 0xa6, 0xd0, 0x35, 0x2, 0x4, 0xee, 0x2a, 0x30, 0xfa, 0xa, 0x9e, 0xb2, 0x4f, 0x66, 0x6e, 0x77, 0x1d, 
                          0x61, 0xed, 0x26, 0xf0, 0x2, 0x1, 0x41, 0xf6, 0x82, 0x41, 0xd6, 0x45, 0x2, 0x4f, 0x17, 0x28, 0xbf, 0x8a, 0xa7, 0x37, 
                          0x3, 0x33, 0x1b, 0x7b, 0xfa, 0x59, 0xa0, 0x7f, 0x4, 0x6e, 0x2e, 0xe0, 0x1e, 0xd9, 0xcd, 0x7, 0x50, 0xf3, 0x9, 0x10, 
                          0x68, 0xff, 0x2f, 0xdd, 0x7a, 0xb3, 0x34, 0x5e, 0x4, 0x8, 0x10, 0xb8, 0xa4, 0xc0, 0xe8, 0x7b, 0xc3, 0x2c, 0x29, 0x2f, 
                          0x39, 0x64, 0x1a, 0x45, 0x80, 0x40, 0x2d, 0x30, 0xfb, 0x2e, 0x33, 0x61, 0xe6, 0x9c, 0x21, 0x40, 0xe0, 0xd2, 0x2, 0xb3, 
                          0x10, 0xcb, 0x8d, 0x17, 0x66, 0x97, 0x1e, 0x46, 0x8d, 0x23, 0xf0, 0x6e, 0x81, 0xf2, 0x5e, 0xd8, 0x2c, 0xac, 0xa2, 0xdf, 
                          0x2e, 0xfb, 0x6e, 0x51, 0xbd, 0x27, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 
                          0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 
                          0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 
                          0x70, 0x7b, 0x81, 0xf2, 0xff, 0x80, 0x54, 0x77, 0xa6, 0xb7, 0x6d, 0xf4, 0x51, 0xa5, 0xfa, 0x2b, 0x7d, 0x66, 0x9f, 0xcf, 
                          0x1c, 0x1d, 0xff, 0xf6, 0xb8, 0x3a, 0x40, 0x80, 0xc0, 0xf9, 0x2, 0xa3, 0x90, 0x99, 0x6d, 0x1b, 0x7d, 0xe5, 0x75, 0x6f, 
                          0x5b, 0xea, 0x51, 0x74, 0xdb, 0xf9, 0xbd, 0x77, 0x4, 0x2, 0x4, 0x1e, 0x21, 0x30, 0xfb, 0xe0, 0x77, 0xd9, 0xc9, 0x68, 
                          0x0, 0xad, 0x7c, 0x5f, 0xd9, 0x6c, 0xb6, 0xf6, 0x8, 0x64, 0x9d, 0x20, 0x40, 0xe0, 0x7c, 0x81, 0xe8, 0xd2, 0x52, 0x90, 
                          0x9d, 0x3f, 0x16, 0x8e, 0x40, 0x80, 0xc0, 0x1, 0x2, 0x5b, 0xc3, 0x6a, 0xb4, 0x5f, 0xb9, 0x9c, 0x9c, 0xcd, 0xc0, 0x56, 
                          0x66, 0x88, 0x7, 0x74, 0x57, 0x15, 0x4, 0x8, 0x3c, 0x41, 0x60, 0x76, 0x1f, 0x2c, 0xf7, 0xb1, 0xfe, 0x6e, 0xb1, 0xe8, 
                          0x7e, 0xbd, 0xa5, 0x69, 0x59, 0xef, 0xac, 0xcc, 0x13, 0x9c, 0xf5, 0x81, 0x0, 0x81, 0x93, 0x5, 0x22, 0x4b, 0xcb, 0x72, 
                          0x56, 0x55, 0xff, 0x7b, 0xb6, 0xad, 0x17, 0x5a, 0x75, 0x48, 0x9a, 0x8d, 0x9d, 0x3c, 0xd0, 0xaa, 0x27, 0x40, 0x60, 0xbf, 
                          0x80, 0xa0, 0xda, 0x6f, 0xa8, 0x6, 0x2, 0x4, 0xbe, 0x2c, 0x20, 0xc8, 0xbe, 0x3c, 0x0, 0xe, 0x4f, 0x80, 0xc0, 0x76, 
                          0x1, 0xdf, 0xdd, 0xbf, 0xdd, 0xce, 0x9e, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0xb8, 
                          0xb8, 0xc0, 0xd6, 0x7b, 0x56, 0xbd, 0x47, 0x2f, 0x7a, 0xf5, 0xed, 0x79, 0xd2, 0xff, 0xe2, 0x84, 0x9a, 0x47, 0x80, 0xc0, 
                          0x91, 0x2, 0xb3, 0x7, 0x52, 0x5b, 0xc7, 0xba, 0x62, 0x90, 0xa5, 0x76, 0x96, 0x8f, 0x83, 0xb4, 0x42, 0xd3, 0x3d, 0xb7, 
                          0x23, 0xcf, 0x1c, 0x75, 0x11, 0xb8, 0x90, 0xc0, 0xec, 0x89, 0xf9, 0xb2, 0xa9, 0x75, 0x50, 0x94, 0xc1, 0x10, 0xd, 0x89, 
                          0x56, 0xd8, 0x44, 0x67, 0x64, 0x5b, 0x3, 0xb4, 0xe6, 0x1e, 0x3d, 0xff, 0x76, 0xa1, 0xa1, 0xd1, 0x14, 0x2, 0x4, 0x56, 
                          0x4, 0xea, 0x59, 0xd9, 0xec, 0x42, 0x1f, 0x5, 0x4a, 0x2b, 0xd0, 0x46, 0x33, 0xa5, 0x51, 0x3b, 0x5b, 0xed, 0x38, 0x2a, 
                          0xcc, 0x56, 0x7c, 0x94, 0x25, 0x40, 0xe0, 0x6, 0x2, 0x75, 0x60, 0xcc, 0x96, 0x9b, 0x7b, 0xc2, 0x64, 0xb6, 0x6f, 0x2f, 
                          0xf4, 0xf2, 0x7e, 0x91, 0x10, 0xed, 0x85, 0xe9, 0xd, 0x86, 0x42, 0x13, 0x9, 0x10, 0x58, 0x15, 0xe8, 0xcd, 0xbc, 0x66, 
                          0xcb, 0xcd, 0xe8, 0x52, 0xb0, 0xd7, 0x9e, 0xc8, 0xc, 0x6d, 0xd4, 0x86, 0xde, 0xfd, 0xaf, 0xd6, 0x12, 0x32, 0xbf, 0x36, 
                          0xb, 0xd0, 0x55, 0x3b, 0xe5, 0x9, 0x10, 0xb8, 0xa0, 0xc0, 0x6c, 0xa6, 0x13, 0x9, 0x84, 0x56, 0x1d, 0xa3, 0xfb, 0x6a, 
                          0xb3, 0x65, 0x65, 0x7d, 0x7f, 0x2e, 0xd2, 0x86, 0xd9, 0x3e, 0xb3, 0x65, 0xf3, 0x5, 0x87, 0x46, 0x93, 0x8, 0x10, 0x88, 
                          0xa, 0x9c, 0x15, 0x64, 0xa3, 0x59, 0xd9, 0xca, 0xb6, 0xd9, 0x72, 0xb7, 0x55, 0x57, 0xbd, 0x1c, 0x9d, 0xcd, 0x34, 0xa3, 
                          0x56, 0xca, 0x11, 0x20, 0x70, 0x51, 0x81, 0xde, 0x3d, 0xa8, 0xd9, 0x12, 0x2f, 0xb2, 0x4c, 0x4c, 0x5d, 0x6e, 0xcd, 0xcc, 
                          0x3e, 0x19, 0x64, 0x7b, 0x97, 0xc3, 0x17, 0x1d, 0x36, 0xcd, 0x22, 0x40, 0x60, 0xb4, 0xc, 0x9b, 0xdd, 0x30, 0x1f, 0x2d, 
                          0x23, 0x6b, 0xd9, 0xd5, 0x10, 0xe9, 0xd5, 0xbd, 0x3a, 0x62, 0xd1, 0x37, 0x8, 0x56, 0xeb, 0x55, 0x9e, 0x0, 0x81, 0xb, 
                          0xb, 0xcc, 0x6e, 0x88, 0xcf, 0x96, 0x77, 0xd1, 0x59, 0xdd, 0xca, 0xbd, 0xb1, 0xd5, 0xfb, 0x62, 0xab, 0xe5, 0x67, 0x7d, 
                          0xbe, 0xf0, 0x70, 0x69, 0x1a, 0x1, 0x2, 0xa3, 0x7b, 0x4a, 0x11, 0x9d, 0x95, 0x59, 0xd3, 0x4a, 0x58, 0xf4, 0xc2, 0x72, 
                          0x6b, 0x1d, 0xa3, 0xe5, 0xeb, 0x4a, 0x9d, 0x11, 0x13, 0x65, 0x8, 0x10, 0xb8, 0x80, 0xc0, 0xea, 0x85, 0x1d, 0xbd, 0x3f, 
                          0xb6, 0x7a, 0x8f, 0xac, 0x5e, 0xf2, 0x46, 0xdb, 0xd5, 0x5a, 0xe, 0xb7, 0xea, 0x8a, 0xd6, 0x77, 0x81, 0x21, 0xd1, 0x4, 
                          0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 
                          0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x3c, 
                          0x4a, 0x20, 0xfa, 0xc1, 0xf4, 0x47, 0x75, 0x5a, 0x67, 0x8, 0x10, 0x78, 0x96, 0xc0, 0xe8, 0x23, 0x4e, 0x1e, 0x52, 0x7d, 
                          0xd6, 0x58, 0xeb, 0xd, 0x81, 0xc7, 0xa, 0x8, 0xb2, 0xc7, 0xe, 0xad, 0x8e, 0x11, 0x78, 0x9e, 0x40, 0xf9, 0xd1, 0xa5, 
                          0xb2, 0x77, 0xe5, 0x87, 0xca, 0xeb, 0x8f, 0x13, 0xd5, 0xdb, 0x5a, 0xfb, 0xe5, 0xd7, 0xcc, 0xde, 0x9e, 0x77, 0xce, 0xe8, 
                          0x11, 0x81, 0x4b, 0x9, 0xcc, 0xbe, 0xbf, 0xac, 0x17, 0x46, 0xbd, 0x60, 0x4b, 0xe5, 0x47, 0x75, 0x5e, 0xaa, 0xf3, 0x1a, 
                          0x43, 0x80, 0xc0, 0x33, 0x4, 0xf6, 0x4, 0x59, 0x64, 0x16, 0x66, 0x36, 0xf6, 0x8c, 0xf3, 0x44, 0x2f, 0x8, 0x5c, 0x5a, 
                          0xa0, 0xfe, 0x46, 0x8c, 0xe8, 0xd7, 0xf2, 0xcc, 0x66, 0x5d, 0x91, 0x2f, 0x49, 0xbc, 0x34, 0x8c, 0xc6, 0x11, 0x20, 0x70, 
                          0x1f, 0x81, 0xe8, 0x23, 0x16, 0xd1, 0xe0, 0xaa, 0x97, 0xa2, 0x66, 0x64, 0xf7, 0x39, 0x17, 0xb4, 0x94, 0xc0, 0x6d, 0x5, 
                          0xce, 0x5a, 0x5a, 0xb6, 0xee, 0x95, 0xdd, 0x16, 0x49, 0xc3, 0x9, 0x10, 0xb8, 0xbe, 0xc0, 0xec, 0x5d, 0xcb, 0x1c, 0x4a, 
                          0xab, 0x8f, 0x63, 0x98, 0x8d, 0x5d, 0x7f, 0xec, 0xb5, 0x90, 0x0, 0x81, 0x89, 0x80, 0x20, 0x73, 0x8a, 0x10, 0x20, 0x70, 
                          0x7b, 0x1, 0x41, 0x76, 0xfb, 0x21, 0xd4, 0x1, 0x2, 0xef, 0x15, 0x98, 0x7d, 0x17, 0xff, 0x7b, 0x65, 0xf4, 0x9c, 0x0, 
                          0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 
                          0x4, 0x8, 0x7c, 0x48, 0x20, 0x7a, 0xb3, 0x3e, 0x5a, 0xee, 0x43, 0xcd, 0x76, 0x18, 0x2, 0x4, 0x8, 0xfc, 0x22, 0x10, 
                          0x7d, 0x64, 0x22, 0x5a, 0x8e, 0x2b, 0x1, 0x2, 0x4, 0x3e, 0x2e, 0x10, 0xd, 0xa8, 0x68, 0xb9, 0x8f, 0x77, 0xc0, 0x1, 
                          0x9, 0x10, 0x78, 0xb7, 0x40, 0xfd, 0x51, 0xa5, 0xde, 0xe7, 0x30, 0xa3, 0xe5, 0xde, 0xad, 0xa9, 0xf7, 0x4, 0x8, 0x7c, 
                          0x4d, 0x20, 0xfa, 0x79, 0xca, 0x68, 0xb9, 0xaf, 0x75, 0xc4, 0x81, 0x9, 0x10, 0x78, 0xaf, 0xc0, 0x68, 0x16, 0x56, 0xaa, 
                          0x44, 0xcb, 0xbd, 0x57, 0x52, 0xcf, 0x9, 0x10, 0xf8, 0x9a, 0x40, 0x34, 0xa0, 0xa2, 0xe5, 0xbe, 0xd6, 0x11, 0x7, 0x26, 
                          0x40, 0xe0, 0xbd, 0x2, 0xd1, 0x80, 0x8a, 0x96, 0x7b, 0xaf, 0xa4, 0x9e, 0x13, 0x20, 0xf0, 0x35, 0x81, 0xd6, 0xbb, 0x91, 
                          0x7b, 0x5e, 0xfb, 0x5a, 0x47, 0x1c, 0x98, 0x0, 0x81, 0xf7, 0xa, 0xec, 0x9, 0x2d, 0x8f, 0x64, 0xbc, 0xf7, 0xbc, 0xd1, 
                          0x73, 0x2, 0x97, 0x17, 0x88, 0x6, 0x54, 0xb4, 0xdc, 0xe5, 0x3b, 0xac, 0x81, 0x4, 0x8, 0x3c, 0x4f, 0x20, 0x1a, 0x50, 
                          0xd1, 0x72, 0xcf, 0x13, 0xd2, 0x23, 0x2, 0x4, 0x2e, 0x2b, 0x10, 0xfd, 0x2c, 0x65, 0xb4, 0xdc, 0x65, 0x3b, 0xaa, 0x61, 
                          0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 
                          0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x7c, 0x49, 0xe0, 0xac, 0xc7, 0x25, 0xce, 0xaa, 0xf7, 0x4b, 0x4c, 
                          0xe, 0x4b, 0x80, 0xc0, 0x95, 0x5, 0xce, 0xa, 0x9c, 0xb3, 0xea, 0xbd, 0xb2, 0xa5, 0xb6, 0x11, 0x20, 0xf0, 0x25, 0x81, 
                          0xb3, 0x2, 0xe7, 0xac, 0x7a, 0xbf, 0xc4, 0xe4, 0xb0, 0x4, 0x8, 0x5c, 0x59, 0xa0, 0xf7, 0xd, 0x16, 0xad, 0x36, 0xe7, 
                          0xb2, 0xf5, 0x17, 0x2a, 0xb6, 0x1e, 0x86, 0x2d, 0xcb, 0xa, 0xb5, 0x2b, 0x9f, 0x1, 0xda, 0x46, 0xe0, 0x1, 0x2, 0xa3, 
                          0x6f, 0x79, 0xad, 0xbb, 0x57, 0x7, 0xd6, 0x28, 0x4, 0x67, 0x65, 0x1f, 0x40, 0xa7, 0xb, 0x4, 0x8, 0x5c, 0x45, 0xa0, 
                          0x35, 0xcb, 0xea, 0xb5, 0x6d, 0x36, 0x7b, 0x1b, 0x85, 0xa2, 0x59, 0xd9, 0x55, 0x46, 0x5c, 0x3b, 0x8, 0x3c, 0x50, 0x20, 
                          0xcf, 0x9c, 0x5a, 0x21, 0x35, 0x9b, 0x55, 0xcd, 0x66, 0x64, 0x25, 0x97, 0x20, 0x7b, 0xe0, 0xc9, 0xa3, 0x4b, 0x4, 0xae, 
                          0x22, 0xb0, 0xba, 0xb4, 0x1c, 0x85, 0x93, 0x19, 0xd9, 0x55, 0x46, 0x55, 0x3b, 0x8, 0xbc, 0x4c, 0x40, 0x90, 0xbd, 0x6c, 
                          0xc0, 0x75, 0x97, 0xc0, 0x13, 0x5, 0x66, 0xf7, 0xbd, 0x66, 0xcb, 0xc3, 0xd1, 0xd2, 0x74, 0xb6, 0xef, 0x13, 0x3d, 0xf5, 
                          0x89, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 
                          0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0xf0, 0x43, 0x20, 0xfa, 0x14, 
                          0x7e, 0xb4, 0x1c, 0x54, 0x2, 0x4, 0x8, 0x7c, 0x5c, 0x60, 0x25, 0xa0, 0xca, 0xe7, 0xc8, 0x56, 0xf6, 0xfb, 0x78, 0xa7, 
                          0x1c, 0x90, 0x0, 0x81, 0xf7, 0x9, 0xb4, 0xbe, 0xaa, 0xe7, 0x7d, 0xa, 0x7a, 0x4c, 0x80, 0xc0, 0xad, 0x5, 0x7a, 0x4f, 
                          0xec, 0xdf, 0xba, 0x53, 0x1a, 0x4f, 0x80, 0xc0, 0xf3, 0x5, 0xea, 0xf0, 0x1a, 0x2d, 0x15, 0xeb, 0x25, 0xa5, 0xe0, 0x7b, 
                          0xfe, 0xf9, 0xa1, 0x87, 0x4, 0x6e, 0x2b, 0xb0, 0x72, 0xdf, 0x6b, 0xa5, 0xec, 0x6d, 0x41, 0x34, 0x9c, 0x0, 0x81, 0x7b, 
                          0xa, 0x44, 0x2, 0x2a, 0x52, 0xe6, 0x9e, 0xbd, 0xd7, 0x6a, 0x2, 0x4, 0x6e, 0x29, 0xd0, 0x5b, 0x36, 0xf6, 0x3a, 0x23, 
                          0xc4, 0x6e, 0x39, 0xcc, 0x1a, 0x4d, 0xe0, 0xb9, 0x2, 0xb3, 0xfb, 0x62, 0x75, 0xcf, 0xdd, 0x1b, 0x7b, 0xee, 0xb9, 0xa0, 
                          0x67, 0x4, 0x6e, 0x29, 0xb0, 0x65, 0x66, 0xb5, 0xf2, 0xc5, 0x8c, 0xb7, 0x44, 0xd1, 0x68, 0x2, 0x4, 0xee, 0x25, 0xb0, 
                          0x1a, 0x64, 0x2b, 0x5f, 0xca, 0x78, 0x2f, 0x9, 0xad, 0x25, 0x40, 0xe0, 0xd6, 0x2, 0x2b, 0x61, 0x26, 0xc8, 0x6e, 0x3d, 
                          0xd4, 0x1a, 0x4f, 0xe0, 0xd9, 0x2, 0xad, 0x9b, 0xfd, 0xad, 0x7b, 0x63, 0x2d, 0x5, 0xf7, 0xcc, 0x9e, 0x7d, 0x6e, 0xe8, 
                          0x1d, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 
                          0x2, 0x4, 0x8, 0xdc, 0x48, 0x60, 0xcf, 0xbb, 0x97, 0xa9, 0x9b, 0x9e, 0x2f, 0xbb, 0xd1, 0x60, 0x6b, 0x2a, 0x81, 0xa7, 
                          0xa, 0x44, 0x83, 0xac, 0x57, 0x4e, 0x90, 0x3d, 0xf5, 0xcc, 0xd0, 0x2f, 0x2, 0x37, 0x12, 0x88, 0x4, 0x59, 0x2f, 0xac, 
                          0x5a, 0xfb, 0x46, 0xea, 0xbb, 0x11, 0x8f, 0xa6, 0x12, 0x20, 0x70, 0x7, 0x81, 0x68, 0xf0, 0xe4, 0x72, 0xf5, 0x7f, 0xeb, 
                          0xe5, 0x65, 0xeb, 0xe7, 0x3b, 0x38, 0x68, 0x23, 0x1, 0x2, 0x37, 0x16, 0x88, 0x6, 0xd9, 0x28, 0xa0, 0x56, 0xea, 0xb8, 
                          0x31, 0x95, 0xa6, 0x13, 0x20, 0x70, 0x55, 0x81, 0xe8, 0x57, 0xf9, 0x44, 0x96, 0x97, 0x2, 0xed, 0xaa, 0xa3, 0xac, 0x5d, 
                          0x4, 0x1e, 0x2e, 0x10, 0x9, 0x9f, 0xde, 0x47, 0x99, 0xea, 0xd7, 0x2d, 0x2b, 0x1f, 0x7e, 0xb2, 0xe8, 0x1e, 0x81, 0xab, 
                          0xa, 0x44, 0x82, 0x2c, 0xb7, 0x7d, 0xa5, 0xec, 0x55, 0xfb, 0xab, 0x5d, 0x4, 0x8, 0x3c, 0x50, 0x60, 0x25, 0x9c, 0x46, 
                          0xef, 0x52, 0xae, 0xd4, 0xf3, 0x40, 0x46, 0x5d, 0x22, 0x40, 0xe0, 0x9b, 0x2, 0x91, 0x0, 0x8a, 0xbc, 0x63, 0xd9, 0x7a, 
                          0x37, 0xf3, 0x9b, 0xfd, 0x72, 0x6c, 0x2, 0x4, 0x5e, 0x24, 0xb0, 0x25, 0xc8, 0xca, 0x7b, 0x61, 0x9e, 0x25, 0x7b, 0xd1, 
                          0xc9, 0xa2, 0xab, 0x4, 0xae, 0x2a, 0x70, 0x64, 0x90, 0x99, 0x95, 0x5d, 0x75, 0x94, 0xb5, 0x8b, 0xc0, 0x43, 0x4, 0x7a, 
                          0x8f, 0x59, 0x8c, 0x5e, 0xaf, 0xbb, 0xde, 0x7b, 0x18, 0xb6, 0xac, 0xe3, 0x21, 0x5c, 0xba, 0x41, 0x80, 0x0, 0x1, 0x2, 
                          0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 
                          0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x81, 0xd7, 0x9, 0xcc, 0x1e, 0x8c, 
                          0xed, 0x7d, 0x8d, 0xcf, 0xeb, 0xa0, 0x74, 0x98, 0x0, 0x81, 0xeb, 0xa, 0xe4, 0x87, 0x5a, 0x5b, 0x2d, 0xac, 0xb7, 0xcd, 
                          0x42, 0xef, 0xba, 0xbd, 0xd4, 0x32, 0x2, 0x4, 0x1e, 0x2d, 0x20, 0xc8, 0x1e, 0x3d, 0xbc, 0x3a, 0x47, 0xe0, 0x1d, 0x2, 
                          0xbd, 0xcf, 0x49, 0x46, 0xbe, 0xa3, 0xff, 0x1d, 0x42, 0x7a, 0x49, 0x80, 0xc0, 0xe5, 0x5, 0x4, 0xd9, 0xe5, 0x87, 0x48, 
                          0x3, 0x9, 0x10, 0x98, 0x9, 0xb4, 0x6e, 0xe6, 0x47, 0xbe, 0xa7, 0x7f, 0x56, 0xaf, 0xed, 0x4, 0x8, 0x10, 0xf8, 0x98, 
                          0x80, 0x20, 0xfb, 0x18, 0xb5, 0x3, 0x11, 0x20, 0x70, 0x96, 0x80, 0x20, 0x3b, 0x4b, 0x56, 0xbd, 0x4, 0x8, 0x7c, 0x4c, 
                          0xa0, 0x7e, 0xa4, 0x62, 0xf4, 0xb3, 0xc7, 0x2f, 0x3e, 0x36, 0x2c, 0xe, 0x44, 0x80, 0xc0, 0x8a, 0x80, 0x20, 0x5b, 0xd1, 
                          0x52, 0x96, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 
                          0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x78, 0xb0, 0x40, 0xf9, 0x99, 
                          0xc9, 0xde, 0xff, 0xb3, 0xb2, 0xec, 0x7e, 0xf4, 0x99, 0xb0, 0xb3, 0xea, 0x7d, 0xf0, 0x50, 0xe8, 0x1a, 0x1, 0x2, 0x5b, 
                          0x5, 0x7a, 0xc1, 0xb4, 0xfa, 0x7a, 0x7d, 0xfc, 0xd5, 0xfd, 0xa3, 0x1, 0xb9, 0xb5, 0x9f, 0xf6, 0x23, 0x40, 0xe0, 0xa1, 
                          0x2, 0xa3, 0xf0, 0x58, 0xd, 0xa2, 0xe8, 0xac, 0x6d, 0x4f, 0xbd, 0xf, 0x1d, 0x6, 0xdd, 0x22, 0x40, 0x60, 0x8f, 0xc0, 
                          0x96, 0x20, 0x4b, 0xc7, 0xab, 0x3f, 0x67, 0x39, 0x7b, 0xca, 0x7f, 0x4b, 0xc8, 0x8d, 0xbe, 0xb8, 0x71, 0x4f, 0x9f, 0xed, 
                          0x4b, 0x80, 0xc0, 0xc3, 0x4, 0x5a, 0x81, 0x14, 0xbd, 0x4f, 0x36, 0xfb, 0x86, 0xd8, 0x4c, 0xd5, 0xab, 0xaf, 0xb5, 0x7f, 
                          0x59, 0xf6, 0x61, 0xd4, 0xba, 0x43, 0x80, 0xc0, 0x59, 0x2, 0x47, 0xcc, 0xc8, 0x5a, 0x6d, 0x3b, 0xab, 0xde, 0xb3, 0x1c, 
                          0xd4, 0x4b, 0x80, 0xc0, 0x8d, 0x5, 0xb6, 0x4, 0x4e, 0xe4, 0xa6, 0xfc, 0x59, 0xf5, 0xde, 0x98, 0x5a, 0xd3, 0x9, 0x10, 
                          0x38, 0x4b, 0xa0, 0x75, 0x6f, 0x6b, 0xb4, 0xbc, 0x8b, 0x84, 0x58, 0x7d, 0xf, 0x2d, 0xff, 0x7c, 0x44, 0xbd, 0x67, 0x39, 
                          0xa8, 0x97, 0x0, 0x81, 0x1b, 0xb, 0xd4, 0xf7, 0xc8, 0xea, 0x9b, 0xf2, 0x2b, 0x37, 0xf1, 0x7b, 0x37, 0xf4, 0x7b, 0x61, 
                          0x19, 0x7d, 0x3, 0xe0, 0xc6, 0xbc, 0x9a, 0x4e, 0x80, 0xc0, 0x27, 0x4, 0x66, 0x41, 0x56, 0xcf, 0xae, 0xb6, 0xcc, 0xc8, 
                          0x7a, 0x61, 0x38, 0x3a, 0xf6, 0x27, 0xfa, 0xee, 0x18, 0x4, 0x8, 0x3c, 0x48, 0x20, 0x7, 0xca, 0x68, 0xf6, 0xb5, 0x25, 
                          0x74, 0xce, 0xaa, 0xf7, 0x41, 0xf4, 0xba, 0x42, 0x80, 0xc0, 0x51, 0x2, 0xbd, 0x47, 0x30, 0x46, 0xf5, 0xb7, 0x1e, 0xa9, 
                          0xa8, 0xcb, 0x9f, 0x55, 0xef, 0x51, 0xfd, 0x56, 0xf, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 
                          0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 
                          0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0xfc, 0xfa, 0x7b, 0xc5, 0xb2, 0x47, 0xfd, 0x8c, 0xd8, 0xc8, 0x69, 
                          0xf6, 0xe1, 0xf0, 0x51, 0x5d, 0xad, 0x7d, 0x57, 0x8e, 0x6d, 0xfc, 0x8, 0x10, 0x20, 0xf0, 0x6f, 0x81, 0xc8, 0x67, 0x29, 
                          0x7b, 0x61, 0xd5, 0x7b, 0x72, 0xbf, 0x55, 0x6f, 0x19, 0x92, 0xad, 0x7f, 0xf7, 0xf6, 0x89, 0x7e, 0x24, 0xca, 0x70, 0x12, 
                          0x20, 0xf0, 0x62, 0x81, 0xe8, 0x47, 0x8f, 0x7a, 0xb3, 0xa7, 0xd5, 0x0, 0xea, 0x1d, 0x6f, 0x36, 0xb3, 0x7b, 0xf1, 0x10, 
                          0xe9, 0x3a, 0x1, 0x2, 0x33, 0x81, 0x68, 0x90, 0xb5, 0xea, 0xd9, 0x32, 0x23, 0x2b, 0xeb, 0x89, 0x1e, 0xdb, 0xac, 0x6c, 
                          0x36, 0x8a, 0xb6, 0x13, 0x78, 0xb9, 0x40, 0x34, 0x4c, 0x6a, 0xa6, 0xe8, 0x92, 0x34, 0xdf, 0xf3, 0x1a, 0x5, 0xe1, 0x68, 
                          0x29, 0x3a, 0xdb, 0xf6, 0xf2, 0xe1, 0xd3, 0x7d, 0x2, 0x4, 0xea, 0x90, 0xe8, 0x7d, 0x6f, 0x58, 0x2b, 0x8c, 0x22, 0x41, 
                          0x56, 0xcf, 0xbe, 0xa2, 0xdf, 0xae, 0x31, 0xb, 0x4d, 0x23, 0x47, 0x80, 0x0, 0x81, 0x5f, 0x9, 0x44, 0x67, 0x64, 0xbd, 
                          0x6f, 0xb2, 0x58, 0x7d, 0x97, 0xd1, 0x3d, 0x32, 0x27, 0x20, 0x1, 0x2, 0x87, 0xb, 0x6c, 0xd, 0xb2, 0xad, 0x4b, 0x45, 
                          0x41, 0x76, 0xf8, 0x10, 0xaa, 0x90, 0x0, 0x81, 0xc8, 0x12, 0x31, 0x1a, 0x76, 0xe5, 0x52, 0x75, 0xf6, 0xc8, 0x46, 0xeb, 
                          0xde, 0xd7, 0xe8, 0x9d, 0x51, 0x23, 0x45, 0x80, 0x0, 0x81, 0xae, 0xc0, 0xea, 0x43, 0xa9, 0xb3, 0x77, 0x10, 0x67, 0x4b, 
                          0xd0, 0xfa, 0xbe, 0x59, 0xeb, 0x7e, 0x58, 0xb9, 0x5c, 0x35, 0x74, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 
                          0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 
                          0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 
                          0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 
                          0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 
                          0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 
                          0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0x10, 
                          0x20, 0x40, 0x80, 0x0, 0x1, 0x2, 0x4, 0x8, 0xd4, 0x2, 0xbf, 0xff, 0xf1, 0xc2, 0x3f, 0x7f, 0xfc, 0xfd, 0x3b, 0x1a, 
                          0x2, 0x4, 0x8, 0xdc, 0x55, 0xe0, 0xcf, 0x3f, 0x1a, 0xfe, 0xaf, 0x1f, 0x7f, 0xff, 0x7a, 0xd7, 0xe, 0x68, 0x37, 0x1, 
                          0x2, 0x4, 0xfe, 0xf6, 0x33, 0xc8, 0x52, 0xa0, 0xf9, 0x43, 0x80, 0x0, 0x81, 0x8f, 0x8, 0xfc, 0xef, 0xcf, 0x65, 0x60, 
                          0x5a, 0xe, 0xa6, 0xbf, 0xff, 0xf8, 0xf1, 0xf7, 0x8f, 0xc5, 0x91, 0xd3, 0x12, 0x31, 0xbd, 0x9e, 0x82, 0x29, 0x6d, 0x4b, 
                          0xff, 0xfe, 0x53, 0xb1, 0x3d, 0xfd, 0x3b, 0xef, 0x97, 0xcb, 0xa4, 0x19, 0x59, 0x5a, 0x62, 0xd6, 0x7f, 0xf2, 0x31, 0xf2, 
                          0xeb, 0x7f, 0xf8, 0xb9, 0x6f, 0x5e, 0x86, 0xa6, 0xe3, 0xe6, 0x63, 0xa4, 0xb2, 0x29, 0x14, 0xcb, 0x3f, 0xb9, 0x2d, 0x69, 
                          0xbf, 0xf4, 0x27, 0xff, 0xdc, 0x3a, 0x56, 0xe3, 0xf0, 0x5e, 0x22, 0x40, 0xe0, 0xa9, 0x2, 0x29, 0x2c, 0x52, 0x68, 0xa4, 
                          0x30, 0xc8, 0xf7, 0xb7, 0xd2, 0xcf, 0xf9, 0x4f, 0xfa, 0x77, 0x5e, 0x2a, 0xa6, 0xd0, 0x2b, 0xc3, 0x28, 0x5, 0x4a, 0xda, 
                          0x96, 0x3, 0x27, 0xcf, 0xc6, 0xca, 0xfd, 0x4b, 0xb7, 0x14, 0x52, 0x65, 0xc8, 0xe5, 0xf2, 0xa9, 0x9e, 0xba, 0xae, 0x14, 
                          0x90, 0x65, 0xdd, 0xa9, 0x9e, 0x3a, 0x8, 0xeb, 0x9f, 0x9f, 0x3a, 0x46, 0xfa, 0x45, 0x80, 0xc0, 0xa2, 0x40, 0x19, 0xe, 
                          0x75, 0x70, 0xe5, 0x9f, 0x53, 0x20, 0xa5, 0x3f, 0x69, 0x46, 0x94, 0xc2, 0xe6, 0xff, 0x7e, 0xfe, 0x9c, 0xc3, 0xa8, 0x17, 
                          0x64, 0xb9, 0x7c, 0xa, 0xcc, 0x5c, 0x57, 0x9e, 0x8d, 0xd5, 0x21, 0x57, 0x7, 0x57, 0x3a, 0x46, 0x3a, 0x56, 0x3e, 0x76, 
                          0xdd, 0xb6, 0xc5, 0x6e, 0x2a, 0x4e, 0x80, 0xc0, 0x93, 0x4, 0xd2, 0x4d, 0xf9, 0x14, 0xe, 0x79, 0x49, 0x57, 0xce, 0x82, 
                          0x72, 0x30, 0xe5, 0xb0, 0xc9, 0x37, 0xf2, 0xff, 0xf2, 0x13, 0xa0, 0x9e, 0x11, 0xe5, 0x59, 0x54, 0xef, 0x1d, 0xcb, 0xb4, 
                          0x5f, 0x9e, 0x91, 0xe5, 0x7f, 0xa7, 0x63, 0xd4, 0xa1, 0x95, 0x7d, 0xcb, 0xfa, 0xeb, 0x37, 0x11, 0xea, 0xb6, 0x3d, 0x69, 
                          0x4c, 0xf4, 0x85, 0x0, 0x81, 0x5, 0x81, 0x3c, 0xb, 0x4a, 0xa1, 0x92, 0x66, 0x3c, 0xe5, 0x52, 0x2f, 0x55, 0x93, 0xc3, 
                          0x26, 0x7, 0x57, 0xa, 0xbd, 0x14, 0x44, 0xf9, 0x1e, 0x59, 0x1d, 0x64, 0x79, 0xff, 0x5c, 0xbe, 0x6e, 0x4a, 0xb9, 0x5c, 
                          0xac, 0x1f, 0xd1, 0xa8, 0xeb, 0xca, 0x33, 0xb0, 0x1c, 0x8a, 0x79, 0x36, 0x97, 0x83, 0x2f, 0xb7, 0xa5, 0x77, 0xac, 0x5, 
                          0x6, 0x45, 0x9, 0x10, 0xb8, 0xb3, 0x40, 0xe, 0x8f, 0xff, 0xf9, 0xd1, 0x89, 0xd6, 0xfd, 0xb1, 0x7a, 0xb9, 0xd7, 0xfb, 
                          0x39, 0x5, 0x54, 0xe, 0x96, 0xde, 0x8d, 0xfe, 0xe4, 0x94, 0x8e, 0x91, 0xb6, 0xe7, 0xbf, 0x39, 0x94, 0xd2, 0xb6, 0xfa, 
                          0xdd, 0xce, 0x7c, 0xef, 0x2e, 0x2f, 0x5b, 0xf3, 0xbd, 0xba, 0xf4, 0x86, 0x40, 0x3a, 0x56, 0xfe, 0x39, 0xdf, 0xe8, 0x77, 
                          0xbf, 0xec, 0xce, 0x67, 0xa2, 0xb6, 0x13, 0xd8, 0x21, 0x90, 0xdf, 0x71, 0x4c, 0x21, 0x90, 0xc3, 0x21, 0xfd, 0x3b, 0xdd, 
                          0x7f, 0x4a, 0x7f, 0x72, 0x38, 0xd4, 0x3f, 0xe7, 0x43, 0xa6, 0x10, 0xc9, 0x4b, 0xd2, 0x32, 0x8, 0x73, 0xf9, 0x56, 0xd3, 
                          0x72, 0x0, 0xb5, 0x96, 0x9f, 0x39, 0xbc, 0x52, 0x99, 0x54, 0x6f, 0x19, 0x74, 0xb9, 0x7d, 0xa9, 0x4c, 0xa, 0x33, 0x37, 
                          0xfe, 0x77, 0xc, 0xbc, 0x5d, 0x9, 0x10, 0xd8, 0x27, 0x90, 0x83, 0xac, 0xc, 0xa9, 0x7d, 0x35, 0xda, 0x9b, 0x0, 0x1, 
                          0x2, 0x1f, 0x14, 0xc8, 0x37, 0xec, 0xeb, 0xe7, 0xc3, 0x3e, 0xd8, 0x4, 0x87, 0x22, 0x40, 0x80, 0xc0, 0x76, 0x81, 0xbc, 
                          0x14, 0xf4, 0x19, 0xcc, 0xed, 0x86, 0xf6, 0x24, 0x40, 0x80, 0x0, 0x81, 0x27, 0xb, 0xfc, 0x3f, 0x8e, 0xb7, 0xb4, 0x83, 
                          0xf2, 0xfa, 0x3e, 0x42, 0x0, 0x0, 0x0, 0x0, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82, };
        #endregion

        /// <summary>
        /// rectの中にpointが入っているかどうかを判定
        /// </summary>
        /// <param name="point"></param>
        /// <param name="rect"></param>
        /// <returns></returns>
        public static bool IsInRectangle( Point point, Rectangle rect ) {
            if ( rect.X <= point.X && point.X <= rect.X + rect.Width ) {
                if ( rect.Y <= point.Y && point.Y <= rect.Y + rect.Height ) {
                    return true;
                }
            }
            return false;
        }

        public static bool Edited {
            get {
                return m_edited;
            }
            set {
                bool old = m_edited;
                m_edited = value;
                if ( EditedChanged != null ) {
                    EditedChanged( typeof( AppManager ), new EventArgs() );
                }
            }
        }

        public static string VERSION {
            get {
#if DEBUG
                return GetAssemblyVersion( typeof( Form1 ) ) + " (build:debug)";
#else
                return GetAssemblyVersion( typeof( Form1 ) ) + " (build:release)";
#endif
            }
        }

        private static string GetAssemblyVersion( Type t ) {
            Assembly a = Assembly.GetAssembly( t );
            AssemblyFileVersionAttribute afva = (AssemblyFileVersionAttribute)Attribute.GetCustomAttribute( a, typeof( AssemblyFileVersionAttribute ) );
            return afva.Version;
        }

        /// <summary>
        /// pictureBox1の行の表示状態を表す配列を取得します。
        /// </summary>
        /// <returns></returns>
        public static int[] GetTimeLineLanes() {
            List<int> ret = new List<int>();
            // vsq
            if ( SaveData.m_group_vsq.Folded ) {
                ret.Add( 1 );
            } else {
                ret.Add( SaveData.m_group_vsq.Count + 1 );
            }
            // character
            for ( int i = 0; i < SaveData.m_groups_character.Count; i++ ) {
                if ( SaveData.m_groups_character[i].Folded ) {
                    ret.Add( 1 );
                } else {
                    ret.Add( SaveData.m_groups_character[i].Count + 1 );
                }
            }
            // telop
            if ( SaveData.TelopListFolded ) {
                ret.Add( 1 );
            } else {
                ret.Add( MaxTelopLanes + 1 );
            }
            // another image
            if ( SaveData.m_group_another.Folded ) {
                ret.Add( 1 );
            } else {
                ret.Add( SaveData.m_group_another.Count + 1 );
            }
            // plugin
            if ( SaveData.m_group_plugin.Folded ) {
                ret.Add( 1 );
            } else {
                ret.Add( SaveData.m_group_plugin.Count + 1 );
            }
            return ret.ToArray();
        }

        /// <summary>
        /// アプリケーションのメイン エントリ ポイントです。
        /// </summary>
        [STAThread]
        static void Main( string[] argv ) {
            Application.EnableVisualStyles();
            Application.SetCompatibleTextRenderingDefault( false );
#if !DEBUG
            try {
#endif
                string file = "";
                if ( argv.Length > 0 ) {
                    file = argv[0];
                }
                Form1 form1 = null;
                if ( File.Exists( file ) ) {
                    form1 = new Form1( file );
                } else {
                    form1 = new Form1( "" );
                }
                Application.Run( form1 );
                Common.LogClose();
#if !DEBUG
            } catch ( Exception e ) {
                Common.LogPush( e );
                Common.LogClose();
            }
#endif
        }

        static AppManager() {
            using ( MemoryStream ms = new MemoryStream( _AUTHOR_LSIT ) ) {
                m_author_list = new Bitmap( ms );
            }
        }

        /// <summary>
        /// 現在保持しているコマンドバッファをクリアします。
        /// </summary>
        public static void ClearCommandBuffer() {
            m_commands.Clear();
            m_command_position = -1;
        }

        /// <summary>
        /// 次回アンドゥ処理されるコマンドの種類を調べます
        /// </summary>
        /// <returns></returns>
        public static CommandType GetNextUndoCommandType() {
            if ( IsUndoAvailable ) {
                return m_commands[m_command_position].type;
            } else {
                return CommandType.nothing;
            }
        }

        /// <summary>
        /// アンドゥ処理を行います
        /// </summary>
        public static void Undo() {
            if ( IsUndoAvailable ) {
                Command run = m_commands[m_command_position];
                Command inv = SaveData.Execute( run );
                m_commands[m_command_position] = inv;
                m_command_position--;
            }
        }

        /// <summary>
        /// 次回リドゥ処理されるコマンドの種類を調べます
        /// </summary>
        /// <returns></returns>
        public static CommandType GetNextRedoCommandType() {
            if ( IsRedoAvailable ) {
                return m_commands[m_command_position + 1].type;
            } else {
                return CommandType.nothing;
            }
        }

        /// <summary>
        /// リドゥ処理を行います
        /// </summary>
        public static void Redo() {
            if ( IsRedoAvailable ) {
                Command run = m_commands[m_command_position + 1];
                Command inv = SaveData.Execute( run );
                m_commands[m_command_position + 1] = inv;
                m_command_position++;
            }
        }

        /// <summary>
        /// リドゥ操作が可能かどうかを表すプロパティ
        /// </summary>
        public static bool IsRedoAvailable {
            get {
                if ( m_commands.Count > 0 && 0 <= m_command_position + 1 && m_command_position + 1 < m_commands.Count ) {
                    return true;
                } else {
                    return false;
                }
            }
        }

        /// <summary>
        /// アンドゥ操作が可能かどうかを表すプロパティ
        /// </summary>
        public static bool IsUndoAvailable {
            get {
                if ( m_commands.Count > 0 && 0 <= m_command_position && m_command_position < m_commands.Count ) {
                    return true;
                } else {
                    return false;
                }
            }
        }
        
        /// <summary>
        /// コマンドバッファに指定されたコマンドを登録します
        /// </summary>
        /// <param name="command"></param>
        public static void Register( Command command ) {
            if ( m_command_position == m_commands.Count - 1 ) {
                // 新しいコマンドバッファを追加する場合
                m_commands.Add( command );
                m_command_position = m_commands.Count - 1;
            } else {
                // 既にあるコマンドバッファを上書きする場合
                //m_commands[m_command_position + 1].Dispose();
                m_commands[m_command_position + 1] = command;
                for ( int i = m_commands.Count - 1; i >= m_command_position + 2; i-- ) {
                    m_commands.RemoveAt( i );
                }
                m_command_position++;
            }
        }

        public static Bitmap author_list {
            get {
                return (Bitmap)m_author_list.Clone();
            }
        }
    }

}
